@@ -41,6 +41,7 @@ OC.L10N.register(
     "Comment:" : "Comentari:",
     "You have a new appointment booking \"%s\" from %s" : "Tens una nova reserva de cita \"%s\" de %s",
     "Dear %s, %s (%s) booked an appointment with you." : "Benvolgut %s, %s (%s) ha reservat una cita amb tu.",
+    "Location:" : "Ubicació:",
     "A Calendar app for Nextcloud" : "Una aplicació de calendari per al Nextcloud",
     "Previous day" : "Dia anterior",
     "Previous week" : "Setmana anterior",
@@ -147,6 +148,7 @@ OC.L10N.register(
     "Share calendar" : "Comparteix el calendari",
     "Unshare from me" : "Deixa de compartir",
     "Save" : "Desa",
+    "View" : "Visualització",
     "Import calendars" : "Importació calendaris",
     "Please select a calendar to import into …" : "Escolliu un calendari per ser importat …",
     "Filename" : "Nom del fitxer",
@@ -166,6 +168,7 @@ OC.L10N.register(
     "Automatic" : "Automàtic",
     "Automatic ({detected})" : "Automàtic ({detected})",
     "New setting was not saved successfully." : "No s'ha desat correctament els nous paràmetres.",
+    "Timezone" : "Fus horari",
     "Navigation" : "Navegació",
     "Previous period" : "Període anterior",
     "Next period" : "Període següent",
@@ -183,7 +186,6 @@ OC.L10N.register(
     "Save edited event" : "Desa l'esdeveniment editat",
     "Delete edited event" : "Suprimeix l'esdeveniment editat",
     "Duplicate event" : "Esdeveniment duplicat",
-    "Shortcut overview" : "Descripció general de la drecera",
     "or" : "o",
     "Calendar settings" : "Paràmetres de Calendari",
     "At event start" : "A l'inici de l'esdeveniment",
@@ -191,19 +193,18 @@ OC.L10N.register(
     "Failed to save default calendar" : "No s'ha pogut desar el calendari predeterminat",
     "CalDAV link copied to clipboard." : "S'ha copiat al porta-retalls l'enllaç CalDAV.",
     "CalDAV link could not be copied to clipboard." : "No s'ha pogut copiar al porta-retalls l'enllaç CalDAV.",
-    "Enable birthday calendar" : "Habilitar el calendari d'aniversaris",
-    "Show tasks in calendar" : "Mostra les tasques en el calendari",
-    "Enable simplified editor" : "Habilitar l'editor simplificat",
-    "Limit the number of events displayed in the monthly view" : "Limita el nombre d'esdeveniments que es mostren a la vista mensual",
-    "Show weekends" : "Mostra els caps de setmana",
-    "Show week numbers" : "Mostra el número de la setmana",
-    "Time increments" : "Increments de temps",
-    "Default calendar for incoming invitations" : "Calendari predeterminat per a les invitacions entrants",
-    "Default reminder" : "Recordatori per defecte",
+    "General" : "General",
+    "Personal availability settings" : "Paràmetres de disponibilitat personal",
     "Copy primary CalDAV address" : "Copia l'adreça CalDAV primària",
     "Copy iOS/macOS CalDAV address" : "Copia l'adreça CalDAV iOS/macOS",
-    "Personal availability settings" : "Paràmetres de disponibilitat personal",
-    "Show keyboard shortcuts" : "Mostra les dreceres del teclat",
+    "Enable birthday calendar" : "Habilitar el calendari d'aniversaris",
+    "Show tasks in calendar" : "Mostra les tasques en el calendari",
+    "Show weekends" : "Mostra els caps de setmana",
+    "Show week numbers" : "Mostra el número de la setmana",
+    "Editing" : "Edició",
+    "Default calendar for incoming invitations" : "Calendari predeterminat per a les invitacions entrants",
+    "Default reminder" : "Recordatori per defecte",
+    "Keyboard shortcuts" : "Dreceres de teclat",
     "Appointment schedule successfully created" : "S'ha creat correctament la planificació de cites",
     "Appointment schedule successfully updated" : "La planificació de cites s'ha actualitzat correctament",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minut","{duration} minuts"],
@@ -268,7 +269,6 @@ OC.L10N.register(
     "Add Talk conversation" : "Afegeix una Converses",
     "Fetching Talk rooms…" : "S'estan obtenint sales de Converses…",
     "No Talk room available" : "No hi ha sala de Converses disponible",
-    "Create a new conversation" : "Crea una conversa nova",
     "Select conversation" : "Seleccioneu una conversa",
     "on" : "a",
     "at" : "a",
@@ -417,6 +417,11 @@ OC.L10N.register(
     "Update this occurrence" : "Actualitza aquesta ocurrència",
     "Public calendar does not exist" : "No existeix un calendari públic",
     "Maybe the share was deleted or has expired?" : "Potser la compartició va ser esborrada o va expirar?",
+    "Remove participant" : "Suprimir el participant",
+    "Yes" : "Sí",
+    "No" : "No",
+    "Maybe" : "Potser",
+    "Create" : "Crea",
     "from {formattedDate}" : "de {formattedDate}",
     "to {formattedDate}" : "a {formattedDate}",
     "on {formattedDate}" : "el {formattedDate}",
@@ -440,7 +445,6 @@ OC.L10N.register(
     "No valid public calendars configured" : "No s'han configurat calendaris públics vàlids",
     "Speak to the server administrator to resolve this issue." : "Parleu amb l'administrador del servidor per resoldre aquest problema.",
     "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Thunderbird proporciona els calendaris de festius. Les dades del calendari es baixaran de {website}",
-    "These public calendars are suggested by the sever administrator. Calendar data will be downloaded from the respective website." : "Aquests calendaris públics els suggereix l'administrador del servidor. Les dades del calendari es descarregaran del lloc web corresponent.",
     "By {authors}" : "Per {authors}",
     "Subscribed" : "Subscrit",
     "Subscribe" : "Subscriu-m'hi",
@@ -478,6 +482,11 @@ OC.L10N.register(
     "Untitled event" : "Esdeveniment sense títol",
     "Close" : "Tanca",
     "Modifications will not get propagated to the organizer and other attendees" : "Les modificacions no es propagaran a l'organitzador i als altres assistents",
+    "Selected" : "Seleccionat",
+    "Title" : "Títol",
+    "30 min" : "30 min",
+    "Participants" : "Participants",
+    "Submit" : "Envia",
     "Subscribe to {name}" : "Subscriure a {name}",
     "Export {name}" : "Exporta {name}",
     "Show availability" : "Mostra disponibilitat",
@@ -579,12 +588,10 @@ OC.L10N.register(
     "Error while parsing a PROPFIND error" : "S'ha produït un error en analitzar un error PROPFIND",
     "Appointment not found" : "No s'ha trobat la cita",
     "User not found" : "No s'ha trobat l'usuari",
-    "Reminder" : "Recordatori",
-    "+ Add reminder" : "+ Afegeix un recordatori",
-    "Select automatic slot" : "Selecció d’interval automàtica",
-    "with" : "amb",
-    "Available times:" : "Horaris disponibles:",
-    "Suggestions" : "Suggeriments",
-    "Details" : "Detalls"
+    "Shortcut overview" : "Descripció general de la drecera",
+    "Enable simplified editor" : "Habilitar l'editor simplificat",
+    "Limit the number of events displayed in the monthly view" : "Limita el nombre d'esdeveniments que es mostren a la vista mensual",
+    "Time increments" : "Increments de temps",
+    "Show keyboard shortcuts" : "Mostra les dreceres del teclat"
 },
 "nplurals=2; plural=(n != 1);");
