@@ -25,6 +25,7 @@ OC.L10N.register(
     "This confirmation link expires in %s hours." : "Mae'r ddolen gadarnhau hon yn dod i ben ymhen %s awr.",
     "Date:" : "Dyddiad:",
     "Where:" : "Lle:",
+    "Location:" : "Lleoliad:",
     "A Calendar app for Nextcloud" : "Ap Calendr ar gyfer Nextcloud",
     "Previous day" : "Diwrnod blaenorol",
     "Previous week" : "Wythnos flaenorol",
@@ -115,6 +116,7 @@ OC.L10N.register(
     "Automatic" : "Awtomatig",
     "Automatic ({detected})" : "Awtomatig ({detected})",
     "New setting was not saved successfully." : "Ni chafodd y gosodiad newydd ei gadw'n llwyddiannus.",
+    "Timezone" : "Cylch amser",
     "Navigation" : "Llywio",
     "Previous period" : "Cyfnod blaenorol",
     "Next period" : "Cyfnod nesaf",
@@ -130,22 +132,20 @@ OC.L10N.register(
     "Close editor" : "Cau'r golygydd",
     "Save edited event" : "Cadw digwyddiad wedi'i olygu",
     "Delete edited event" : "Dileu digwyddiad wedi'i olygu",
-    "Shortcut overview" : "Trosolwg llwybr byr",
     "or" : "neu",
     "No reminder" : "Dim nodyn atgoffa",
     "CalDAV link copied to clipboard." : "Dolen CalDAV wedi'i chopïo i'r clipfwrdd.",
     "CalDAV link could not be copied to clipboard." : "Nid oedd modd copïo dolen CalDAV i'r clipfwrdd.",
-    "Enable birthday calendar" : "Galluogi calendr pen-blwydd",
-    "Show tasks in calendar" : "Dangos tasgau yn y calendr",
-    "Enable simplified editor" : "Galluogi golygydd symlach",
-    "Show weekends" : "Dangos penwythnosau",
-    "Show week numbers" : "Dangos rhifau wythnosau",
-    "Time increments" : "Cynyddiadau amser",
-    "Default reminder" : "Nodyn atgoffa rhagosodedig",
+    "General" : "Cyffredinol",
+    "Personal availability settings" : "Gosodiadau argaeledd personol",
     "Copy primary CalDAV address" : "Copïo prig gyfeiriad CalDAV",
     "Copy iOS/macOS CalDAV address" : "Copïo cyfeiriad CalDAV iOS/macOS",
-    "Personal availability settings" : "Gosodiadau argaeledd personol",
-    "Show keyboard shortcuts" : "Dangos llwybrau byr bysellfwrdd",
+    "Enable birthday calendar" : "Galluogi calendr pen-blwydd",
+    "Show tasks in calendar" : "Dangos tasgau yn y calendr",
+    "Show weekends" : "Dangos penwythnosau",
+    "Show week numbers" : "Dangos rhifau wythnosau",
+    "Default reminder" : "Nodyn atgoffa rhagosodedig",
+    "Keyboard shortcuts" : "Llwybrau byr bysellfwrdd",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} munud","{duration} funud","{duration} munud","{duration} munud"],
     "0 minutes" : "0 munud",
     "_{duration} hour_::_{duration} hours_" : ["{duration} awr","{duration} awr","{duration} awr","{duration} awr"],
@@ -290,6 +290,8 @@ OC.L10N.register(
     "Update this occurrence" : "Diweddaru'r digwyddiad hwn",
     "Public calendar does not exist" : "Nid oes calendr cyhoeddus yn bodoli",
     "Maybe the share was deleted or has expired?" : "Efallai bod y gyfran wedi'i dileu neu wedi dod i ben?",
+    "Yes" : "Ie",
+    "No" : "Na",
     "from {formattedDate}" : "o {formattedDate}",
     "to {formattedDate}" : "i {formattedDate}",
     "on {formattedDate}" : "ar {formattedDate}",
@@ -413,6 +415,10 @@ OC.L10N.register(
     "An error occurred, unable to delete the calendar." : "Bu gwall, ni fu modd dileu'r calendr.",
     "Imported {filename}" : "Mewnforiwyd {filename}",
     "Appointment not found" : "Apwyntiad heb ei ganfod",
-    "User not found" : "Defnyddiwr heb ei ganfod"
+    "User not found" : "Defnyddiwr heb ei ganfod",
+    "Shortcut overview" : "Trosolwg llwybr byr",
+    "Enable simplified editor" : "Galluogi golygydd symlach",
+    "Time increments" : "Cynyddiadau amser",
+    "Show keyboard shortcuts" : "Dangos llwybrau byr bysellfwrdd"
 },
 "nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
