@@ -41,6 +41,7 @@ OC.L10N.register(
     "Comment:" : "Kommentar:",
     "You have a new appointment booking \"%s\" from %s" : "Du har en ny aftale booking \"%s\" fra %s",
     "Dear %s, %s (%s) booked an appointment with you." : "Kære %s, %s (%s) bookede en aftale med dig.",
+    "Location:" : "Sted:",
     "A Calendar app for Nextcloud" : "En kalender-app til Nextcloud",
     "Previous day" : "Forrige dag",
     "Previous week" : "Forrige uge",
@@ -167,6 +168,7 @@ OC.L10N.register(
     "Automatic" : "Automatisk",
     "Automatic ({detected})" : "Automatisk ({detected})",
     "New setting was not saved successfully." : "Den nye indstilling blev ikke gemt.",
+    "Timezone" : "Tidszone",
     "Navigation" : "Navigation",
     "Previous period" : "Tidligere periode",
     "Next period" : "Næste periode",
@@ -184,7 +186,6 @@ OC.L10N.register(
     "Save edited event" : "Gem redigeret begivenhed",
     "Delete edited event" : "Slet redigeret begivenhed",
     "Duplicate event" : "Dubleret begivenhed",
-    "Shortcut overview" : "Genvejsoversigt",
     "or" : "eller",
     "Calendar settings" : "Kalender indstillinger",
     "At event start" : "Ved arrangementets start",
@@ -192,19 +193,18 @@ OC.L10N.register(
     "Failed to save default calendar" : "Kunne ikke gemme standard kalenderen",
     "CalDAV link copied to clipboard." : "CalDAV-linket er kopieret til udklipsholderen.",
     "CalDAV link could not be copied to clipboard." : "CalDAV-linket kunne ikke kopieres til udklipsholderen.",
-    "Enable birthday calendar" : "Slå fødselsdagskalender til",
-    "Show tasks in calendar" : "Vis opgaver i kalenderen",
-    "Enable simplified editor" : "Slå simpel editor til",
-    "Limit the number of events displayed in the monthly view" : "Begræns antallet af hændelser, der vises i månedsvisningen",
-    "Show weekends" : "Vis weekender",
-    "Show week numbers" : "Vis ugenummer ",
-    "Time increments" : "Tidsintervaller",
-    "Default calendar for incoming invitations" : "Standard kalender for indkomne invitationer",
-    "Default reminder" : "Standard påmindelse",
+    "General" : "Generelt",
+    "Personal availability settings" : "Personlige tilgængelighedsindstillinger",
     "Copy primary CalDAV address" : "Kopier primær CalDAV-adresse",
     "Copy iOS/macOS CalDAV address" : "Kopier iOS/macOS CalDAV adresse",
-    "Personal availability settings" : "Personlige tilgængelighedsindstillinger",
-    "Show keyboard shortcuts" : "Vis tastaturgenveje",
+    "Enable birthday calendar" : "Slå fødselsdagskalender til",
+    "Show tasks in calendar" : "Vis opgaver i kalenderen",
+    "Show weekends" : "Vis weekender",
+    "Show week numbers" : "Vis ugenummer ",
+    "Editing" : "Redigering",
+    "Default calendar for incoming invitations" : "Standard kalender for indkomne invitationer",
+    "Default reminder" : "Standard påmindelse",
+    "Keyboard shortcuts" : "Tastaturgenveje",
     "Appointment schedule successfully created" : "Aftaleplanlægning blev oprettet",
     "Appointment schedule successfully updated" : "Aftaleplanlægningen er opdateret",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minut","{duration} minutter"],
@@ -417,6 +417,9 @@ OC.L10N.register(
     "Update this occurrence" : "Opdater denne forekomst",
     "Public calendar does not exist" : "Offentlig kalender findes ikke",
     "Maybe the share was deleted or has expired?" : "Måske er delingen blevet slettet eller er udløbet?",
+    "Yes" : "Ja",
+    "No" : "Nej",
+    "Create" : "Opret",
     "from {formattedDate}" : "fra {formattedDate}",
     "to {formattedDate}" : "til {formattedDate}",
     "on {formattedDate}" : "på {formattedDate}",
@@ -462,7 +465,7 @@ OC.L10N.register(
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Den automatiske tidszoneregistrering bestemte, at din tidszone var UTC.\nDette er højst sandsynligt resultatet af sikkerhedsforanstaltninger i din webbrowser.\nIndstil venligst din tidszone manuelt i kalenderindstillingerne.",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Din konfigurerede tidszone ({timezoneId}) blev ikke fundet. Falder tilbage til UTC.\nSkift venligst din tidszone i indstillingerne og rapporter dette problem.",
     "Availability of {displayName}" : "Tilgængelighed af {displayName}",
-    "Edit event" : "Rediger begivenhed",
+    "Edit event" : "Redigér begivenhed",
     "Event does not exist" : "Begivenheden eksisterer ikke",
     "Duplicate" : "dubletter",
     "Delete this occurrence" : "Slet denne forekomst",
@@ -477,6 +480,11 @@ OC.L10N.register(
     "Untitled event" : "Unavngiven begivenhed",
     "Close" : "Luk",
     "Modifications will not get propagated to the organizer and other attendees" : "Ændringer vil ikke blive udbredt til organisatoren eller andre deltagere",
+    "Selected" : "Markeret",
+    "Title" : "Titel",
+    "30 min" : "30 min",
+    "Participants" : "Deltagere",
+    "Submit" : "Send",
     "Subscribe to {name}" : "Abonner på {name}",
     "Export {name}" : "Eksporter {name}",
     "Show availability" : "Vis tilgængelighed",
@@ -577,6 +585,11 @@ OC.L10N.register(
     "This is an event reminder." : "Dette er en begivenhedspåmindelse.",
     "Error while parsing a PROPFIND error" : "Fejl under parsing af en PROPFIND-fejl",
     "Appointment not found" : "Aftale ikke fundet",
-    "User not found" : "Bruger ikke fundet"
+    "User not found" : "Bruger ikke fundet",
+    "Shortcut overview" : "Genvejsoversigt",
+    "Enable simplified editor" : "Slå simpel editor til",
+    "Limit the number of events displayed in the monthly view" : "Begræns antallet af hændelser, der vises i månedsvisningen",
+    "Time increments" : "Tidsintervaller",
+    "Show keyboard shortcuts" : "Vis tastaturgenveje"
 },
 "nplurals=2; plural=(n != 1);");
