@@ -40,6 +40,8 @@ OC.L10N.register(
     "Comment:" : "Σχόλιο:",
     "You have a new appointment booking \"%s\" from %s" : "Έχετε μια νέα κράτηση για το ραντεβού \"%s\" από τον/την %s",
     "Dear %s, %s (%s) booked an appointment with you." : "Αγαπητέ/ή %s, %s (%s) έκανε κράτηση σε ένα ραντεβού σας.",
+    "Location:" : "Τοποθεσία:",
+    "Duration:" : "Διάρκεια:",
     "A Calendar app for Nextcloud" : "Eφαρμογή ημερολογίου για το Nextcloud",
     "Previous day" : "Προηγούμενη ημέρα",
     "Previous week" : "Προηγούμενη εβδομάδα",
@@ -162,6 +164,7 @@ OC.L10N.register(
     "Automatic" : "Αυτόματο",
     "Automatic ({detected})" : "Αυτόματα ({detected})",
     "New setting was not saved successfully." : "Οι νέες ρυθμίσεις δεν αποθηκεύτηκαν επιτυχώς.",
+    "Timezone" : "Ζώνη ώρας",
     "Navigation" : "Πλοήγηση",
     "Previous period" : "Προηγούμενη περίοδος",
     "Next period" : "Επόμενη περίοδος",
@@ -179,24 +182,21 @@ OC.L10N.register(
     "Save edited event" : "Αποθήκευση επεξεργασμένης εκδήλωσης",
     "Delete edited event" : "Διαγραφή επεξεργασμένης εκδήλωσης",
     "Duplicate event" : "Αντιγραφή εκδήλωσης",
-    "Shortcut overview" : "Επισκόπηση συντόμευσης",
     "or" : "ή",
     "Calendar settings" : "Ρυθμίσεις ημερολογίου",
     "No reminder" : "Χωρίς υπενθύμιση",
     "CalDAV link copied to clipboard." : "Αντιγράφηκε στο πρόχειρο ο σύνδεσμος CalDAV",
     "CalDAV link could not be copied to clipboard." : "Δεν αντιγράφηκε στο πρόχειρο ο σύνδεσμος CalDAV",
-    "Enable birthday calendar" : "Ενεργοποίηση ημερολογίου γενεθλίων",
-    "Show tasks in calendar" : "Εμφάνιση εργασιών στο ημερολόγιο",
-    "Enable simplified editor" : "Ενεργοποίηση απλοποιημένου προγράμματος επεξεργασίας",
-    "Limit the number of events displayed in the monthly view" : "Περιορισμός του αριθμού των συμβάντων που εμφανίζονται στη μηνιαία προβολή",
-    "Show weekends" : "Εμφάνιση σαββατοκύριακων",
-    "Show week numbers" : "Εμφάνιση αριθμού εβδομάδας",
-    "Time increments" : "Χρόνος μεταξύ δυο ραντεβού",
-    "Default reminder" : "Προεπιλεγμένη υπενθύμιση",
+    "General" : "Γενικά",
+    "Personal availability settings" : "Ρυθμίσεις προσωπικής διαθεσιμότητας",
     "Copy primary CalDAV address" : "Αντιγραφή κύριας διεύθυνσης CalDAV",
     "Copy iOS/macOS CalDAV address" : "Αντιγραφή διεύθυνσης iOS/macOS CalDAV",
-    "Personal availability settings" : "Ρυθμίσεις προσωπικής διαθεσιμότητας",
-    "Show keyboard shortcuts" : "Εμφάνιση συντομεύσεων πληκτρολογίου",
+    "Enable birthday calendar" : "Ενεργοποίηση ημερολογίου γενεθλίων",
+    "Show tasks in calendar" : "Εμφάνιση εργασιών στο ημερολόγιο",
+    "Show weekends" : "Εμφάνιση σαββατοκύριακων",
+    "Show week numbers" : "Εμφάνιση αριθμού εβδομάδας",
+    "Default reminder" : "Προεπιλεγμένη υπενθύμιση",
+    "Keyboard shortcuts" : "Συντομεύσεις πληκτρολογίου",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} λεπτό","{duration} λεπτά"],
     "0 minutes" : "0  λεπτά",
     "_{duration} hour_::_{duration} hours_" : ["{duration} ώρα","{duration} ώρες"],
@@ -375,6 +375,9 @@ OC.L10N.register(
     "Update this occurrence" : "Ενημερώστε αυτό το περιστατικό",
     "Public calendar does not exist" : "Το δημόσιο ημερολόγιο δεν υπάρχει",
     "Maybe the share was deleted or has expired?" : "Ίσως το κοινόχρηστο διαγράφηκε ή δεν υπάρχει;",
+    "Yes" : "Ναι",
+    "No" : "Όχι",
+    "Create" : "Δημιουργία",
     "from {formattedDate}" : "από {formattedDate}",
     "to {formattedDate}" : "έως {formattedDate}",
     "on {formattedDate}" : "σε {formattedDate}",
@@ -430,6 +433,11 @@ OC.L10N.register(
     "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Συνημμένο που απαιτεί κοινόχρηστη πρόσβαση","Συνημμένα που απαιτούν κοινόχρηστη πρόσβαση"],
     "Untitled event" : "Συμβάν χωρίς τίτλο",
     "Close" : "Κλείσιμο",
+    "Selected" : "Επιλεγμένο",
+    "Title" : "Τίτλος",
+    "30 min" : "30 λεπτά",
+    "Participants" : "Συμμετέχοντες",
+    "Submit" : "Υποβολή",
     "Subscribe to {name}" : "Εγγραφείτε στον {name}",
     "Export {name}" : "Εξαγωγη {name}",
     "Anniversary" : "Επέτειος",
@@ -519,6 +527,11 @@ OC.L10N.register(
     "Imported {filename}" : "Εισηγμένο {filename}",
     "This is an event reminder." : "Αυτή είναι μια υπενθύμιση γεγονότος.",
     "Appointment not found" : "Το ραντεβού δεν βρέθηκε",
-    "User not found" : "Ο/Η χρήστης δεν βρέθηκε"
+    "User not found" : "Ο/Η χρήστης δεν βρέθηκε",
+    "Shortcut overview" : "Επισκόπηση συντόμευσης",
+    "Enable simplified editor" : "Ενεργοποίηση απλοποιημένου προγράμματος επεξεργασίας",
+    "Limit the number of events displayed in the monthly view" : "Περιορισμός του αριθμού των συμβάντων που εμφανίζονται στη μηνιαία προβολή",
+    "Time increments" : "Χρόνος μεταξύ δυο ραντεβού",
+    "Show keyboard shortcuts" : "Εμφάνιση συντομεύσεων πληκτρολογίου"
 },
 "nplurals=2; plural=(n != 1);");
