@@ -8,6 +8,7 @@ OC.L10N.register(
     "Upcoming events" : "Próximos eventos",
     "Calendar" : "Calendario",
     "Confirm" : "Confirmar",
+    "Location:" : "Ubicación:",
     "A Calendar app for Nextcloud" : "Una aplicación de calendario para Nextcloud",
     "Previous day" : "Día previo",
     "Previous week" : "Semana previa",
@@ -50,9 +51,13 @@ OC.L10N.register(
     "Filename" : "Nombre de archivo",
     "Cancel" : "Cancelar",
     "Automatic" : "Automático",
+    "Timezone" : "Zona horaria",
     "List view" : "Vista de lista",
     "Actions" : "Acciones",
+    "General" : "General",
     "Show week numbers" : "Mostrar número de semana",
+    "Editing" : "Editando",
+    "Keyboard shortcuts" : "Atajos de teclado",
     "Update" : "Actualizar",
     "Location" : "Ubicación",
     "Description" : "Descripción",
@@ -93,6 +98,7 @@ OC.L10N.register(
     "first" : "primero",
     "Resources" : "Recursos",
     "available" : "disponible",
+    "Yes" : "Sí",
     "Global" : "Global",
     "Subscribe" : "Suscribirse",
     "Select a date" : "Elija una fecha",
@@ -100,7 +106,9 @@ OC.L10N.register(
     "Edit event" : "Editar evento",
     "All day" : "Todo el día",
     "Close" : "Cerrar",
+    "30 min" : "30 minutos",
     "Participants" : "Participantes",
+    "Submit" : "Enviar",
     "Anniversary" : "Aniversario",
     "Week {number} of {year}" : "Semana {number} de {year}",
     "Daily" : "Diariamente",
