@@ -12,6 +12,7 @@ OC.L10N.register(
     "Confirm" : "Confirmar",
     "Description:" : "Descripción:",
     "Where:" : "Dónde:",
+    "Location:" : "Ubicación:",
     "Today" : "Hoy",
     "Day" : "Día",
     "Week" : "Semana",
@@ -21,6 +22,7 @@ OC.L10N.register(
     "Copy link" : "Copiar enlace",
     "Edit" : "Editar",
     "Delete" : "Borrar",
+    "Calendars" : "Calendarios",
     "New calendar" : "Nuevo calendario",
     "Export" : "Exportar",
     "Empty trash bin" : "Vacíar la papelera",
@@ -37,10 +39,13 @@ OC.L10N.register(
     "Filename" : "Nombre del archivo",
     "Cancel" : "Cancelar",
     "Automatic" : "Automático",
+    "Timezone" : "Zona horaria",
     "List view" : "Vista de lista",
     "Actions" : "Acciones",
     "or" : "o",
+    "General" : "General",
     "Show week numbers" : "Mostrar número de semana",
+    "Keyboard shortcuts" : "Atajos del teclado",
     "Update" : "Actualizar",
     "Location" : "Ubicación",
     "Description" : "Descripción",
@@ -66,17 +71,20 @@ OC.L10N.register(
     "Decline" : "Declinar",
     "Tentative" : "Tentativo",
     "Attendees" : "Asistentes",
-    "All day" : "Todo el día",
     "Repeat" : "Repetir",
     "never" : "nunca",
     "after" : "después",
+    "Resources" : "Recursos",
     "available" : "disponible",
     "Global" : "Global",
     "Subscribe" : "Suscribir",
     "Personal" : "Personal",
-    "Details" : "Detalles",
-    "Resources" : "Recursos",
+    "Edit event" : "Editar evento",
+    "All day" : "Todo el día",
     "Close" : "Cerrar",
+    "Title" : "Título",
+    "Participants" : "Participantes",
+    "Submit" : "Enviar",
     "Anniversary" : "Aniversario",
     "Week {number} of {year}" : "Semana {number} de {year}",
     "Daily" : "Diariamente",
