@@ -10,6 +10,7 @@ OC.L10N.register(
     "Confirm" : "Confirmar",
     "Description:" : "Descripción:",
     "Where:" : "Dónde:",
+    "Location:" : "Ubicación:",
     "Today" : "Hoy",
     "Day" : "Día",
     "Week" : "Semana",
@@ -34,11 +35,14 @@ OC.L10N.register(
     "Filename" : "Nombre del archivo",
     "Cancel" : "Cancelar",
     "Automatic" : "Automático",
-    "or" : "o",
+    "Timezone" : "Zona horaria",
     "List view" : "Vista de lista",
     "Actions" : "Acciones",
+    "or" : "o",
+    "General" : "General",
     "Show week numbers" : "Mostrar número de semana",
-    "Show keyboard shortcuts" : "Mostrar atajos de teclado",
+    "Keyboard shortcuts" : "Atajos del teclado",
+    "Update" : "Actualizar",
     "Location" : "Ubicación",
     "Description" : "Descripción",
     "to" : "para",
@@ -50,13 +54,15 @@ OC.L10N.register(
     "Friday" : "Viernes",
     "Saturday" : "Sábado",
     "Sunday" : "Domingo",
-    "Update" : "Actualizar",
     "Your email address" : "Tu dirección de correo electrónico",
     "Notification" : "Notificación",
     "Email" : "Correo electrónico",
-    "Delete file" : "Borrar archivo",
+    "hours" : "horas",
+    "days" : "días",
+    "weeks" : "semanas",
     "Choose a file to add as attachment" : "Selecciona el archivo a agregar como adjunto",
     "Choose a file to share as a link" : "Selecciona un archivo para compartir como enlace",
+    "Delete file" : "Borrar archivo",
     "Unknown" : "Desconocido",
     "Accept" : "Aceptar",
     "Decline" : "Declinar",
@@ -64,17 +70,19 @@ OC.L10N.register(
     "Attendees" : "Asistentes",
     "From" : "De",
     "To" : "Para",
-    "All day" : "Todo el día",
     "Repeat" : "Repetir",
     "never" : "nunca",
     "after" : "después",
+    "Resources" : "Recursos",
     "available" : "disponible",
     "Global" : "Global",
     "Subscribe" : "Suscribir",
     "Personal" : "Personal",
-    "Details" : "Detalles",
-    "Resources" : "Recursos",
+    "Edit event" : "Editar evento",
+    "All day" : "Todo el día",
     "Close" : "Cerrar",
+    "Participants" : "Participantes",
+    "Submit" : "Enviar",
     "Anniversary" : "Aniversario",
     "Week {number} of {year}" : "Semana {number} de {year}",
     "Daily" : "Diariamente",
@@ -86,6 +94,7 @@ OC.L10N.register(
     "Status" : "Estatus",
     "Confirmed" : "Confirmado",
     "Categories" : "Categorías",
-    "User not found" : "No se encontró el usuario"
+    "User not found" : "No se encontró el usuario",
+    "Show keyboard shortcuts" : "Mostrar atajos de teclado"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
