@@ -41,6 +41,7 @@ OC.L10N.register(
     "Comment:" : "Comentario:",
     "You have a new appointment booking \"%s\" from %s" : "Tiene una nueva reservación \"%s\" de %s",
     "Dear %s, %s (%s) booked an appointment with you." : "Estimado(a) %s, %s (%s) ha reservado una cita con Ud.",
+    "Location:" : "Ubicación:",
     "A Calendar app for Nextcloud" : "Una aplicación de Calendario para Nextcloud",
     "Previous day" : "Día anterior",
     "Previous week" : "Semana anterior",
@@ -167,6 +168,7 @@ OC.L10N.register(
     "Automatic" : "Automático",
     "Automatic ({detected})" : "Automático ({detected})",
     "New setting was not saved successfully." : "No se guardó correctamente la nueva configuración.",
+    "Timezone" : "Zona horaria",
     "Navigation" : "Navegación",
     "Previous period" : "Periodo anterior",
     "Next period" : "Periodo siguiente",
@@ -184,7 +186,6 @@ OC.L10N.register(
     "Save edited event" : "Guardar evento editado",
     "Delete edited event" : "Eliminar evento editado",
     "Duplicate event" : "Duplicar evento",
-    "Shortcut overview" : "Vista general de atajos",
     "or" : "o",
     "Calendar settings" : "Configuración del calendario",
     "At event start" : "Al comienzo del evento",
@@ -192,19 +193,18 @@ OC.L10N.register(
     "Failed to save default calendar" : "No se pudo guardar el calendario predeterminado",
     "CalDAV link copied to clipboard." : "Enlace CalDAV copiado al portapapeles.",
     "CalDAV link could not be copied to clipboard." : "No se pudo copiar el enlace CalDAV al portapapeles.",
-    "Enable birthday calendar" : "Habilitar el calendario de cumpleaños",
-    "Show tasks in calendar" : "Mostrar tareas en el calendario",
-    "Enable simplified editor" : "Habilitar el editor simplificado",
-    "Limit the number of events displayed in the monthly view" : "Limitar el número de eventos mostrados en la vista mensual",
-    "Show weekends" : "Mostrar fines de semana",
-    "Show week numbers" : "Mostrar número de semana",
-    "Time increments" : "Incrementos de tiempo",
-    "Default calendar for incoming invitations" : "Calendario predeterminado para aceptar invitaciones",
-    "Default reminder" : "Recordatorio predeterminado",
+    "General" : "General",
+    "Personal availability settings" : "Configuración de disponibilidad personal",
     "Copy primary CalDAV address" : "Copiar la dirección CalDAV principal",
     "Copy iOS/macOS CalDAV address" : "Copiar la dirección iOS/macOS CalDAV",
-    "Personal availability settings" : "Configuración de disponibilidad personal",
-    "Show keyboard shortcuts" : "Mostrar atajos de teclado",
+    "Enable birthday calendar" : "Habilitar el calendario de cumpleaños",
+    "Show tasks in calendar" : "Mostrar tareas en el calendario",
+    "Show weekends" : "Mostrar fines de semana",
+    "Show week numbers" : "Mostrar número de semana",
+    "Editing" : "Editando",
+    "Default calendar for incoming invitations" : "Calendario predeterminado para aceptar invitaciones",
+    "Default reminder" : "Recordatorio predeterminado",
+    "Keyboard shortcuts" : "Atajos del teclado",
     "Appointment schedule successfully created" : "El cronograma de citas fue creado exitosamente",
     "Appointment schedule successfully updated" : "El cronograma de citas fue actualizado exitosamente",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minuto","{duration} minutos","{duration} minutos"],
@@ -400,6 +400,7 @@ OC.L10N.register(
     "Public calendar does not exist" : "El calendario público no existe",
     "Maybe the share was deleted or has expired?" : "¿Quizá el recurso compartido fue eliminado o caducó?",
     "Maybe" : "Tal vez",
+    "Create" : "Crear",
     "from {formattedDate}" : "desde {formattedDate}",
     "to {formattedDate}" : "hasta {formattedDate}",
     "on {formattedDate}" : "el {formattedDate}",
@@ -457,7 +458,9 @@ OC.L10N.register(
     "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Adjunto que requiere acceso compartido","Adjuntos que requieren acceso compartido","Adjuntos que requieren acceso compartido"],
     "Untitled event" : "Evento sin título",
     "Close" : "Cerrar",
+    "30 min" : "30 min",
     "Participants" : "Participantes",
+    "Submit" : "Enviar",
     "Subscribe to {name}" : "Subscribir a {name}",
     "Export {name}" : "Exportar {name}",
     "Anniversary" : "Aniversario",
@@ -549,6 +552,11 @@ OC.L10N.register(
     "This is an event reminder." : "Esto es un recordatorio del evento.",
     "Error while parsing a PROPFIND error" : "Error al analizar un error PROPFIND",
     "Appointment not found" : "Cita no encontrada",
-    "User not found" : "No se encontró el usuario"
+    "User not found" : "No se encontró el usuario",
+    "Shortcut overview" : "Vista general de atajos",
+    "Enable simplified editor" : "Habilitar el editor simplificado",
+    "Limit the number of events displayed in the monthly view" : "Limitar el número de eventos mostrados en la vista mensual",
+    "Time increments" : "Incrementos de tiempo",
+    "Show keyboard shortcuts" : "Mostrar atajos de teclado"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
