@@ -41,6 +41,8 @@ OC.L10N.register(
     "Comment:" : "Iruzkina:",
     "You have a new appointment booking \"%s\" from %s" : "\"%s\" hitzordu berri bat duzu %s-tik",
     "Dear %s, %s (%s) booked an appointment with you." : " %s estimatua, %s (%s)-k zurekin hitzordua erreserbatu du.",
+    "Location:" : "Kokapena:",
+    "Duration:" : "Iraupena:",
     "A Calendar app for Nextcloud" : "Nextclouderako egutegi app-a",
     "Previous day" : "Aurreko eguna",
     "Previous week" : "Aurreko astea",
@@ -147,6 +149,8 @@ OC.L10N.register(
     "Share calendar" : "Partekatu egutegia",
     "Unshare from me" : "Kendu nirekin partekatzea",
     "Save" : "Gorde",
+    "No title" : "Izenbururik ez",
+    "View" : "Ikusi",
     "Import calendars" : "Inportatu egutegiak",
     "Please select a calendar to import into …" : "Hautatu egutegia hona inportatzeko ...",
     "Filename" : "Fitxategi-izena",
@@ -166,6 +170,7 @@ OC.L10N.register(
     "Automatic" : "Automatikoa",
     "Automatic ({detected})" : "Automatikoa ({detected})",
     "New setting was not saved successfully." : "Ezarpen berria ez da behar bezala gorde.",
+    "Timezone" : "Ordu-zona",
     "Navigation" : "Nabigazioa",
     "Previous period" : "Aurreko aldia",
     "Next period" : "Hurrengo aldia",
@@ -183,7 +188,6 @@ OC.L10N.register(
     "Save edited event" : "Gorde editatutako gertaera",
     "Delete edited event" : "Ezabatu editatutako gertaera",
     "Duplicate event" : "Bikoiztu gertaera",
-    "Shortcut overview" : "Lasterbideen informazio orokorra",
     "or" : "edo",
     "Calendar settings" : "Egutegiaren ezarpenak",
     "At event start" : "Gertaeraren hasieran",
@@ -191,19 +195,18 @@ OC.L10N.register(
     "Failed to save default calendar" : "Egutegi lehenetsia gordetzeak huts egin du",
     "CalDAV link copied to clipboard." : "CalDAV esteka arbelera kopiatu da.",
     "CalDAV link could not be copied to clipboard." : "Ezin izan da CalDAV helbidea arbelera kopiatu.",
-    "Enable birthday calendar" : "Gaitu urtebetetzeen egutegia",
-    "Show tasks in calendar" : "Erakutsi zereginak egutegian",
-    "Enable simplified editor" : "Gaitu editore sinplifikatua",
-    "Limit the number of events displayed in the monthly view" : "Mugatu hileroko ikuspegian bistaratzen diren gertaeren kopurua",
-    "Show weekends" : "Erakutsi asteburuak",
-    "Show week numbers" : "Erakutsi aste zenbakiak",
-    "Time increments" : " \nDenbora-gehikuntzak",
-    "Default calendar for incoming invitations" : "Jasotako gonbidapenetarako egutegi lehenetsia",
-    "Default reminder" : "Gogorarazpen lehenetsia",
+    "General" : "Orokorra",
+    "Personal availability settings" : "Eskuragarritasun pertsonalaren ezarpenak",
     "Copy primary CalDAV address" : "Kopiatu CalDAV helbide nagusia",
     "Copy iOS/macOS CalDAV address" : "Kopiatu iOS/macOS CalDAV helbidea",
-    "Personal availability settings" : "Eskuragarritasun pertsonalaren ezarpenak",
-    "Show keyboard shortcuts" : "Erakutsi teklatuaren lasterbideak",
+    "Enable birthday calendar" : "Gaitu urtebetetzeen egutegia",
+    "Show tasks in calendar" : "Erakutsi zereginak egutegian",
+    "Show weekends" : "Erakutsi asteburuak",
+    "Show week numbers" : "Erakutsi aste zenbakiak",
+    "Editing" : "Edizioa",
+    "Default calendar for incoming invitations" : "Jasotako gonbidapenetarako egutegi lehenetsia",
+    "Default reminder" : "Gogorarazpen lehenetsia",
+    "Keyboard shortcuts" : "Teklatuaren lasterbideak",
     "Appointment schedule successfully created" : "Hitzorduaren ordutegia ondo sortu da",
     "Appointment schedule successfully updated" : "Hitzorduaren ordutegia ondo eguneratu da",
     "_{duration} minute_::_{duration} minutes_" : ["minutu {duration}","{duration} minutu"],
@@ -258,7 +261,6 @@ OC.L10N.register(
     "Could not book the appointment. Please try again later or contact the organizer." : "Ezin izan da hitzordua erreserbatu. Saiatu berriro geroago edo jarri harremanetan administratzalearekin.",
     "Back" : "Itzuli",
     "Book appointment" : "Erreserbatu hitzordua",
-    "Create a new conversation" : "Sortu elkarrizketa berri bat",
     "Select conversation" : "Hautatu elkarrizketa",
     "on" : "noiz",
     "at" : "non",
@@ -401,6 +403,11 @@ OC.L10N.register(
     "Update this occurrence" : "Eguneratu gertaera hau",
     "Public calendar does not exist" : "Egutegi publikoa ez da existitzen",
     "Maybe the share was deleted or has expired?" : "Agian, partekatutakoa ezabatu egin da edo iraungita geratu da?",
+    "Remove participant" : "Partehartzailea borratu",
+    "Yes" : "Bai",
+    "No" : "Ez",
+    "Maybe" : "Agian",
+    "Create" : "Sortu",
     "from {formattedDate}" : "{formattedDate}tik ",
     "to {formattedDate}" : "{formattedDate} arte ",
     "on {formattedDate}" : "{formattedDate}an",
@@ -424,7 +431,6 @@ OC.L10N.register(
     "No valid public calendars configured" : "Ez dago baliozko egutegi publikorik konfiguratuta",
     "Speak to the server administrator to resolve this issue." : "Hitz egin zerbitzariko administratzailearekin arazo hau konpontzeko.",
     "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Jaiegun egutegi publikoak Thunderbird-ek hornitzen ditu. Egutegiaren datuak {website}(e)tik deskargatuko dira.",
-    "These public calendars are suggested by the sever administrator. Calendar data will be downloaded from the respective website." : "Egutegi publiko hauek zerbitzariko administratzaileak proposatzen ditu. Egutegien datuak dagokien webgunetik deskargatuko dira.",
     "By {authors}" : "{authors} egina",
     "Subscribed" : "Harpidetua",
     "Subscribe" : "Harpidetu",
@@ -459,6 +465,11 @@ OC.L10N.register(
     "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Sarbide partekatua behar duen eranskina","Sarbide partekatua behar duten eranskinak"],
     "Untitled event" : "Izenik gabeko gertaera",
     "Close" : "Itxi",
+    "Selected" : "Hautatua",
+    "Title" : "Izenburua",
+    "30 min" : "30 min",
+    "Participants" : "Parte hartzaileak",
+    "Submit" : "Bidali",
     "Subscribe to {name}" : "Harpidetu {name}",
     "Export {name}" : "Esportatu {name}",
     "Anniversary" : "Urtebetetzea",
@@ -552,12 +563,10 @@ OC.L10N.register(
     "Error while parsing a PROPFIND error" : "Errore bat gertatu da PROPFIND errore bat analizatzean",
     "Appointment not found" : "Ez da hitzordua aurkitu",
     "User not found" : "Ez da erabiltzailea aurkitu",
-    "Reminder" : "Gogorarazpena",
-    "+ Add reminder" : "+ Gehitu gogorarazpena",
-    "Select automatic slot" : "Hautatu tartea automatikoki",
-    "with" : "honekin",
-    "Available times:" : "Denbora eskuragarriak:",
-    "Suggestions" : "Iradokizunak",
-    "Details" : "Xehetasunak"
+    "Shortcut overview" : "Lasterbideen informazio orokorra",
+    "Enable simplified editor" : "Gaitu editore sinplifikatua",
+    "Limit the number of events displayed in the monthly view" : "Mugatu hileroko ikuspegian bistaratzen diren gertaeren kopurua",
+    "Time increments" : " \nDenbora-gehikuntzak",
+    "Show keyboard shortcuts" : "Erakutsi teklatuaren lasterbideak"
 },
 "nplurals=2; plural=(n != 1);");
