@@ -163,6 +163,7 @@ OC.L10N.register(
     "Automatic" : "Automaattinen",
     "Automatic ({detected})" : "Automaattinen ({detected})",
     "New setting was not saved successfully." : "Uutta asetusta ei tallennettu onnistuneesti.",
+    "Timezone" : "Aikavyöhyke",
     "Navigation" : "Navigointi",
     "Previous period" : "Edellinen jakso",
     "Next period" : "Seuraava jakso",
@@ -180,7 +181,6 @@ OC.L10N.register(
     "Save edited event" : "Tallenna muokattu tapahtuma",
     "Delete edited event" : "Poista muokattu tapahtuma",
     "Duplicate event" : "Tee kaksoiskappale tapahtumasta",
-    "Shortcut overview" : "Pikakuvakenäkymä",
     "or" : "tai",
     "Calendar settings" : "Kalenteriasetukset",
     "At event start" : "Tapahtuman alkaessa",
@@ -188,19 +188,17 @@ OC.L10N.register(
     "Failed to save default calendar" : "Oletuskalenterin tallentaminen epäonnistui",
     "CalDAV link copied to clipboard." : "CalDAV-linkki kopioitu leikepöydälle.",
     "CalDAV link could not be copied to clipboard." : "CalDAV-linkkiä ei voitu kopioida leikepöydälle.",
-    "Enable birthday calendar" : "Käytä syntymäpäiväkalenteria",
-    "Show tasks in calendar" : "Näytä tehtävät kalenterissa",
-    "Enable simplified editor" : "Käytä yksinkertaistettua muokkainta",
-    "Limit the number of events displayed in the monthly view" : "Rajoita kuukausinäkymässä näytettävien tapahtumien määrää",
-    "Show weekends" : "Näytä viikonloput",
-    "Show week numbers" : "Näytä viikkonumerot",
-    "Time increments" : "Aikavälit",
-    "Default calendar for incoming invitations" : "Oletuskalenteri saapuville kutsuille",
-    "Default reminder" : "Oletusmuistutus",
+    "General" : "Yleiset",
+    "Personal availability settings" : "Henkilökohtaiset saatavuusasetukset",
     "Copy primary CalDAV address" : "Kopioi ensisijainen CalDAV-osoite",
     "Copy iOS/macOS CalDAV address" : "Kopioi iOS:in/macOS:n CalDAV-osoite",
-    "Personal availability settings" : "Henkilökohtaiset saatavuusasetukset",
-    "Show keyboard shortcuts" : "Näytä pikanäppäimet",
+    "Enable birthday calendar" : "Käytä syntymäpäiväkalenteria",
+    "Show tasks in calendar" : "Näytä tehtävät kalenterissa",
+    "Show weekends" : "Näytä viikonloput",
+    "Show week numbers" : "Näytä viikkonumerot",
+    "Default calendar for incoming invitations" : "Oletuskalenteri saapuville kutsuille",
+    "Default reminder" : "Oletusmuistutus",
+    "Keyboard shortcuts" : "Pikanäppäimet",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minuutti","{duration} minuuttia"],
     "0 minutes" : "0 minuuttia",
     "_{duration} hour_::_{duration} hours_" : ["{duration} tunti","{duration} tuntia"],
@@ -397,7 +395,10 @@ OC.L10N.register(
     "Update this occurrence" : "Päivitä tämä esiintymä",
     "Public calendar does not exist" : "Julkista kalenteria ei ole olemassa",
     "Maybe the share was deleted or has expired?" : "Kenties jako poistettiin tai se vanheni.",
+    "Yes" : "Kyllä",
+    "No" : "Ei",
     "Maybe" : "Ehkä",
+    "Create" : "Luo",
     "from {formattedDate}" : "alkaen {formattedDate}",
     "to {formattedDate}" : "päättyen {formattedDate}",
     "on {formattedDate}" : "päivänä {formattedDate}",
@@ -449,7 +450,11 @@ OC.L10N.register(
     "_User requires access to your file_::_Users require access to your file_" : ["Käyttäjä tarvitsee pääsyn tiedostoosi","Käyttäjät tarvitsevat pääsyn tiedostoosi"],
     "Untitled event" : "Nimetön tapahtuma",
     "Close" : "Sulje",
+    "Selected" : "Valittu",
+    "Title" : "Nimeke",
+    "30 min" : "30 min",
     "Participants" : "Osallistujat",
+    "Submit" : "Lähetä",
     "Subscribe to {name}" : "Tilaa {name}",
     "Export {name}" : "Vie {name}",
     "Show availability" : "Näytä saatavuus",
@@ -547,6 +552,11 @@ OC.L10N.register(
     "Imported {filename}" : "Tuotiin {filename}",
     "This is an event reminder." : "Tämä on tapahtuman muistutus.",
     "Appointment not found" : "Tapaamista ei löydy",
-    "User not found" : "Käyttäjää ei löydy"
+    "User not found" : "Käyttäjää ei löydy",
+    "Shortcut overview" : "Pikakuvakenäkymä",
+    "Enable simplified editor" : "Käytä yksinkertaistettua muokkainta",
+    "Limit the number of events displayed in the monthly view" : "Rajoita kuukausinäkymässä näytettävien tapahtumien määrää",
+    "Time increments" : "Aikavälit",
+    "Show keyboard shortcuts" : "Näytä pikanäppäimet"
 },
 "nplurals=2; plural=(n != 1);");
