@@ -170,6 +170,7 @@ OC.L10N.register(
     "Automatic" : "Automatico",
     "Automatic ({detected})" : "Automático ({detected})",
     "New setting was not saved successfully." : "O novo axuste non foi fardado correctamente.",
+    "Timezone" : "Fuso horario",
     "Navigation" : "Navegación",
     "Previous period" : "Período anterior",
     "Next period" : "Período seguinte",
@@ -187,7 +188,6 @@ OC.L10N.register(
     "Save edited event" : "Gardar o evento editado",
     "Delete edited event" : "Eliminar o evento editado",
     "Duplicate event" : "Evento duplicado",
-    "Shortcut overview" : "Vista xeral dos atallos",
     "or" : "ou",
     "Calendar settings" : "Axustes de Calendario",
     "At event start" : "No inicio do evento",
@@ -195,19 +195,18 @@ OC.L10N.register(
     "Failed to save default calendar" : "Produciuse un fallo ao gardar o calendario predeterminado",
     "CalDAV link copied to clipboard." : "Copiada a ligazón CalDAV ao portapapeis.",
     "CalDAV link could not be copied to clipboard." : "Non foi posíbel copiar a ligazón CalDAV ao portapapeis.",
-    "Enable birthday calendar" : "Activar o calendario de aniversarios",
-    "Show tasks in calendar" : "Amosar as tarefas no calendario",
-    "Enable simplified editor" : "Activar o editor simplificado",
-    "Limit the number of events displayed in the monthly view" : "Limite o número de eventos que se amosan na vista mensual",
-    "Show weekends" : "Amosar os fins de semana",
-    "Show week numbers" : "Amosar o número de semana",
-    "Time increments" : "Incrementos de tempo",
-    "Default calendar for incoming invitations" : "Calendario predeterminado para os convites entrantes",
-    "Default reminder" : "Lembrete predeterminado",
+    "General" : "Xeral",
+    "Personal availability settings" : "Configuración persoal de dispoñibilidade",
     "Copy primary CalDAV address" : "Copiar o enderezo principal do CalDAV",
     "Copy iOS/macOS CalDAV address" : "Copiar o enderezo CalDAV de iOS/macOS",
-    "Personal availability settings" : "Configuración persoal de dispoñibilidade",
-    "Show keyboard shortcuts" : "Amosar os atallos de teclado",
+    "Enable birthday calendar" : "Activar o calendario de aniversarios",
+    "Show tasks in calendar" : "Amosar as tarefas no calendario",
+    "Show weekends" : "Amosar os fins de semana",
+    "Show week numbers" : "Amosar o número de semana",
+    "Editing" : "Editando",
+    "Default calendar for incoming invitations" : "Calendario predeterminado para os convites entrantes",
+    "Default reminder" : "Lembrete predeterminado",
+    "Keyboard shortcuts" : "Atallos de teclado",
     "Appointment schedule successfully created" : "O calendario de citas foi creado correctamente",
     "Appointment schedule successfully updated" : "O calendario de citas foi actualizado correctamente",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minuto","{duration} minutos"],
@@ -418,7 +417,10 @@ OC.L10N.register(
     "Update this occurrence" : "Actualizar esta recorrencia",
     "Public calendar does not exist" : "O calendario público non existe",
     "Maybe the share was deleted or has expired?" : "Quizais a acción foi eliminada ou caducou.",
+    "Yes" : "Si",
+    "No" : "Non",
     "Maybe" : "Quizais",
+    "Create" : "Crear",
     "from {formattedDate}" : "desde {formattedDate}",
     "to {formattedDate}" : "ata {formattedDate}",
     "on {formattedDate}" : "o {formattedDate}",
@@ -479,7 +481,11 @@ OC.L10N.register(
     "Untitled event" : "Evento sen título",
     "Close" : "Pechar",
     "Modifications will not get propagated to the organizer and other attendees" : "As modificacións non van ser propagadas ao organizador e a outros asistentes",
+    "Selected" : "Seleccionado",
+    "Title" : "Titulo",
+    "30 min" : "30 min",
     "Participants" : "Participantes",
+    "Submit" : "Enviar",
     "Subscribe to {name}" : "Subscribirse a {name}",
     "Export {name}" : "Exportar {name}",
     "Show availability" : "Amosar a dispoñibilidade",
@@ -579,6 +585,11 @@ OC.L10N.register(
     "This is an event reminder." : "Este é un lembrete de eventos.",
     "Error while parsing a PROPFIND error" : "Produciuse un erro ao analizar un erro PROPFIND",
     "Appointment not found" : "Non se atopou a cita",
-    "User not found" : "Non se atopou o usuario"
+    "User not found" : "Non se atopou o usuario",
+    "Shortcut overview" : "Vista xeral dos atallos",
+    "Enable simplified editor" : "Activar o editor simplificado",
+    "Limit the number of events displayed in the monthly view" : "Limite o número de eventos que se amosan na vista mensual",
+    "Time increments" : "Incrementos de tempo",
+    "Show keyboard shortcuts" : "Amosar os atallos de teclado"
 },
 "nplurals=2; plural=(n != 1);");
