@@ -37,6 +37,7 @@ OC.L10N.register(
     "Comment:" : "הערה:",
     "You have a new appointment booking \"%s\" from %s" : "קיבלת זימון חדש לפגישה \"%s\" מ%s",
     "Dear %s, %s (%s) booked an appointment with you." : "היי %s, %s (%s) זימן פגישה איתך.",
+    "Location:" : "מיקום:",
     "A Calendar app for Nextcloud" : "יישומון לוח שנה ל־Nextcloud",
     "Previous day" : "יום לאחור",
     "Previous week" : "שבוע לאחור",
@@ -137,6 +138,7 @@ OC.L10N.register(
     "Share calendar" : "שיתוף לוח השנה",
     "Unshare from me" : "ביטול השיתוף איתי",
     "Save" : "שמור",
+    "View" : "צפייה",
     "Import calendars" : "יבוא לוחות שנה",
     "Please select a calendar to import into …" : "בחר לוח שנה לייבוא אליו …",
     "Filename" : "שם קובץ",
@@ -149,6 +151,7 @@ OC.L10N.register(
     "Automatic" : "אוטומטי",
     "Automatic ({detected})" : "אוטומטי ({detected})",
     "New setting was not saved successfully." : "ההגדרה החדשה לא נשמרה בהצלחה.",
+    "Timezone" : "אזור זמן",
     "Navigation" : "ניווט",
     "Previous period" : "התקופה הקודמת",
     "Next period" : "התקופה הבאה",
@@ -160,19 +163,18 @@ OC.L10N.register(
     "Actions" : "פעולות",
     "Create event" : "יצירת אירוע",
     "Show shortcuts" : "הצגת קיצורי דרך",
-    "Shortcut overview" : "סקירת קיצור דרך",
     "or" : "או",
     "No reminder" : "אין תזכורת",
     "CalDAV link copied to clipboard." : "קישור ה־CalDAV הועתק ללוח הגזירים.",
     "CalDAV link could not be copied to clipboard." : "לא ניתן להעתיק את קישור ה־CalDAV ללוח הגזירים.",
-    "Enable birthday calendar" : "אפשר לוח שנה ליום הולדת ",
-    "Show tasks in calendar" : "הצג משימות בלוח השנה",
-    "Enable simplified editor" : "אפשר עורך פשוט",
-    "Show weekends" : "הצגת סופי שבוע",
-    "Show week numbers" : "הצגת מספרי שבועות",
+    "General" : "כללי",
     "Copy primary CalDAV address" : "העתקת כתובת CalDAV עיקרית",
     "Copy iOS/macOS CalDAV address" : "העתקת כתובת CalDAV ל־iOS/macOS",
-    "Show keyboard shortcuts" : "הצגת קיצורי מקלדת",
+    "Enable birthday calendar" : "אפשר לוח שנה ליום הולדת ",
+    "Show tasks in calendar" : "הצג משימות בלוח השנה",
+    "Show weekends" : "הצגת סופי שבוע",
+    "Show week numbers" : "הצגת מספרי שבועות",
+    "Keyboard shortcuts" : "קיצורי מקלדת",
     "Update" : "עדכון",
     "Location" : "מיקום",
     "Description" : "תיאור",
@@ -201,7 +203,6 @@ OC.L10N.register(
     "Edit time" : "עריכת שעה",
     "Save time" : "שמירת שעה",
     "Remove reminder" : "הסרת תזכורת",
-    "+ Add reminder" : "+ הוספת תזכורת",
     "seconds" : "שניות",
     "minutes" : "דקות",
     "hours" : "שעות",
@@ -212,14 +213,15 @@ OC.L10N.register(
     "Proceed" : "להמשיך",
     "Delete file" : "מחיקת קבצים",
     "Available" : "זמינות",
+    "Availability of attendees, resources and rooms" : "זמינות של משתתפים, משאבים וחדרים",
+    "Out of office" : "מחוץ למשרד",
+    "Attendees:" : "משתתפים:",
+    "Done" : "הסתיים",
+    "Room name" : "שם החדר",
     "Free" : "פנוי",
     "Busy (tentative)" : "תפוס (טנטטיבי)",
     "Busy" : "עסוק",
-    "Out of office" : "מחוץ למשרד",
     "Unknown" : "לא ידוע",
-    "Availability of attendees, resources and rooms" : "זמינות של משתתפים, משאבים וחדרים",
-    "Done" : "הסתיים",
-    "Room name" : "שם החדר",
     "Accept" : "אשר",
     "Decline" : "דחייה",
     "Tentative" : "טנטטיבית",
@@ -240,7 +242,6 @@ OC.L10N.register(
     "Event title" : "כותרת האירוע",
     "From" : "מאת",
     "To" : "אל",
-    "All day" : "כל היום",
     "Repeat" : "חזרה",
     "_time_::_times_" : ["בשעה","בשעה","בשעות"],
     "never" : "לעולם לא",
@@ -261,6 +262,7 @@ OC.L10N.register(
     "weekend day" : "יום בסופ״ש",
     "Does not repeat" : "אינו חוזר",
     "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "הגדרת ה-recurrence (=הישנות) של אירוע זה אינה נתמכת במלואה על ידי Nextcloud. אם אתה עורך את ה-recurrence-options, הישנות מסוימות עשויות לאבד.",
+    "Resources" : "משאבים",
     "Update this and all future" : "עדכון של זה והעתידיים",
     "Update this occurrence" : "עדכון המופע הזה",
     "Public calendar does not exist" : "לוח השנה הציבורי אינו קיים",
@@ -280,14 +282,16 @@ OC.L10N.register(
     "Subscribe" : "הרשמה",
     "Time:" : "שעה:",
     "Personal" : "אישי",
+    "Edit event" : "עריכת אירוע",
     "Event does not exist" : "האירוע לא קיים",
     "Delete this occurrence" : "מחיקת המופע הזה",
     "Delete this and all future" : "מחיקת זה והבאים",
-    "Details" : "פרטים",
+    "All day" : "כל היום",
     "Invite" : "הזמנה",
-    "Resources" : "משאבים",
     "Untitled event" : "אירוע ללא כותרת",
     "Close" : "סגירה",
+    "Participants" : "משתתפים",
+    "Submit" : "שליחה",
     "Subscribe to {name}" : "הרשמה אל {name}",
     "Anniversary" : "יום השנה",
     "Appointment" : "פגישה",
@@ -368,6 +372,9 @@ OC.L10N.register(
     "Error while sharing file" : "שגיאה בשיתוף הקובץ",
     "An error occurred, unable to delete the calendar." : "אירעה שגיאה, לא ניתן למחוק את היומן.",
     "Imported {filename}" : "יובא {filename} ",
-    "User not found" : "המשתמש לא נמצא"
+    "User not found" : "המשתמש לא נמצא",
+    "Shortcut overview" : "סקירת קיצור דרך",
+    "Enable simplified editor" : "אפשר עורך פשוט",
+    "Show keyboard shortcuts" : "הצגת קיצורי מקלדת"
 },
 "nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
