@@ -111,6 +111,7 @@ OC.L10N.register(
     "Automatic" : "Automatsko",
     "Automatic ({detected})" : "Automatsko ({detected})",
     "New setting was not saved successfully." : "Nova postavka nije uspješno spremljena.",
+    "Timezone" : "Vremenska zona",
     "Navigation" : "Navigacija",
     "Previous period" : "Prethodno razdoblje",
     "Next period" : "Sljedeće razdoblje",
@@ -122,21 +123,20 @@ OC.L10N.register(
     "Actions" : "Radnje",
     "Create event" : "Stvori događaj",
     "Show shortcuts" : "Prikaži prečace",
-    "Shortcut overview" : "Pregled prečaca",
     "or" : "ili",
     "No reminder" : "Nema podsjetnika",
     "CalDAV link copied to clipboard." : "Poveznica kalendara CalDAV kopirana je u međuspremnik.",
     "CalDAV link could not be copied to clipboard." : "Poveznica kalendara CalDAV nije kopirana u međuspremnik.",
-    "Enable birthday calendar" : "Omogući kalendar rođendana",
-    "Show tasks in calendar" : "Prikaži zadatke u kalendaru",
-    "Enable simplified editor" : "Omogući jednostavan uređivač",
-    "Show weekends" : "Prikaži vikende",
-    "Show week numbers" : "Prikaži brojeve tjedana",
-    "Time increments" : "Vremenski prirasti",
-    "Default reminder" : "Zadani podsjetnik",
+    "General" : "Općenito",
     "Copy primary CalDAV address" : "Kopiraj primarnu CalDAV adresu",
     "Copy iOS/macOS CalDAV address" : "Kopiraj iOS/macOS CalDAV adresu",
-    "Show keyboard shortcuts" : "Prikaži tipkovne prečace",
+    "Enable birthday calendar" : "Omogući kalendar rođendana",
+    "Show tasks in calendar" : "Prikaži zadatke u kalendaru",
+    "Show weekends" : "Prikaži vikende",
+    "Show week numbers" : "Prikaži brojeve tjedana",
+    "Editing" : "Uređivanje",
+    "Default reminder" : "Zadani podsjetnik",
+    "Keyboard shortcuts" : "Tipkovni prečaci",
     "Update" : "Ažuriraj",
     "Location" : "Lokacija",
     "Description" : "Opis",
@@ -249,6 +249,9 @@ OC.L10N.register(
     "Update this occurrence" : "Ažuriraj ovo ponavljanje",
     "Public calendar does not exist" : "Javni kalendar ne postoji",
     "Maybe the share was deleted or has expired?" : "Možda je dijeljenje izbrisano ili je isteklo?",
+    "Yes" : "Da",
+    "No" : "Ne",
+    "Create" : "Stvori",
     "from {formattedDate}" : "od {formattedDate}",
     "to {formattedDate}" : "do {formattedDate}",
     "on {formattedDate}" : "{formattedDate}",
@@ -277,7 +280,10 @@ OC.L10N.register(
     "Invite" : "Poziv",
     "Untitled event" : "Događaj bez naslova",
     "Close" : "Zatvori",
+    "Selected" : "Odabrano",
+    "Title" : "Naslov",
     "Participants" : "Sudionici",
+    "Submit" : "Šalji",
     "Subscribe to {name}" : "Pretplati se na {name}",
     "Anniversary" : "Godišnjica",
     "Appointment" : "Dogovor",
@@ -361,6 +367,10 @@ OC.L10N.register(
     "Error while sharing file" : "Pogreška pri dijeljenju datoteke",
     "An error occurred, unable to delete the calendar." : "Došlo je do pogreške, nije moguće izbrisati kalendar.",
     "Imported {filename}" : "Uvezena datoteka {filename}",
-    "User not found" : "Korisnik nije pronađen"
+    "User not found" : "Korisnik nije pronađen",
+    "Shortcut overview" : "Pregled prečaca",
+    "Enable simplified editor" : "Omogući jednostavan uređivač",
+    "Time increments" : "Vremenski prirasti",
+    "Show keyboard shortcuts" : "Prikaži tipkovne prečace"
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
