@@ -155,18 +155,18 @@ OC.L10N.register(
     "Actions" : "Tindakan",
     "Create event" : "Buat acara",
     "Show shortcuts" : "Tampilkan pintasan",
-    "Shortcut overview" : "Ikhtisar pintasan",
     "or" : "atau",
     "CalDAV link copied to clipboard." : "Tautan CalDAV disalin ke papan klip",
     "CalDAV link could not be copied to clipboard." : "Tautan CalDAV tidak dapat disalin ke papan klip",
-    "Enable birthday calendar" : "Aktifkan kalender ulang tahun",
-    "Show tasks in calendar" : "Tampilkan tugas dalam kalender",
-    "Enable simplified editor" : "Aktifkan editor serderhana",
-    "Show weekends" : "Tampilkan akhir pekan",
-    "Show week numbers" : "Tampilkan nomor pekan",
+    "General" : "Umum",
     "Copy primary CalDAV address" : "Salin alamat utama CalDAV",
     "Copy iOS/macOS CalDAV address" : "Salin alamat CalDAV iOS/macOS",
-    "Show keyboard shortcuts" : "Tampilkan pintasan papan kunci",
+    "Enable birthday calendar" : "Aktifkan kalender ulang tahun",
+    "Show tasks in calendar" : "Tampilkan tugas dalam kalender",
+    "Show weekends" : "Tampilkan akhir pekan",
+    "Show week numbers" : "Tampilkan nomor pekan",
+    "Editing" : "Pengeditan",
+    "Keyboard shortcuts" : "Pintasan keyboard",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} menit"],
     "_{duration} hour_::_{duration} hours_" : ["{duration} jam"],
     "To configure appointments, add your email address in personal settings." : "Untuk mengonfigurasi janji temu, tambahkan alamat email Anda di pengaturan pribadi.",
@@ -343,6 +343,9 @@ OC.L10N.register(
     "Custom color" : "Warna khusus",
     "Special color of this event. Overrides the calendar-color." : "Warna spesial dari acara ini. Mengganti warna kalender.",
     "An error occurred, unable to delete the calendar." : "Terjadi galat, tidak dapat menghapus kalender.",
-    "This is an event reminder." : "Ini adalah pengingat acara."
+    "This is an event reminder." : "Ini adalah pengingat acara.",
+    "Shortcut overview" : "Ikhtisar pintasan",
+    "Enable simplified editor" : "Aktifkan editor serderhana",
+    "Show keyboard shortcuts" : "Tampilkan pintasan papan kunci"
 },
 "nplurals=1; plural=0;");
