@@ -41,6 +41,7 @@ OC.L10N.register(
     "Comment:" : "コメント:",
     "You have a new appointment booking \"%s\" from %s" : "新しい予定の予約 \"%s\" が %s からあります。",
     "Dear %s, %s (%s) booked an appointment with you." : "親愛なる %s、%s (%s) はあなたのアポイントメントを予約しました。",
+    "Location:" : "場所：",
     "A Calendar app for Nextcloud" : "NextCloudのカレンダーアプリ",
     "Previous day" : "前日",
     "Previous week" : "前週",
@@ -146,6 +147,7 @@ OC.L10N.register(
     "Share calendar" : "カレンダー共有",
     "Unshare from me" : "共有を自分から解除",
     "Save" : "保存",
+    "View" : "表示",
     "Import calendars" : "カレンダーのインポート",
     "Please select a calendar to import into …" : "インポートするカレンダーを選択してください …",
     "Filename" : "ファイル名",
@@ -165,6 +167,7 @@ OC.L10N.register(
     "Automatic" : "自動",
     "Automatic ({detected})" : "自動 ({detected})",
     "New setting was not saved successfully." : "新しい設定は正常に保存されませんでした。",
+    "Timezone" : "タイムゾーン",
     "Navigation" : "ナビゲーション",
     "Previous period" : "前の期間",
     "Next period" : "次の期間",
@@ -182,7 +185,6 @@ OC.L10N.register(
     "Save edited event" : "編集したイベントを保存",
     "Delete edited event" : "編集したイベントを削除",
     "Duplicate event" : "イベントを複製",
-    "Shortcut overview" : "概要",
     "or" : "或いは",
     "Calendar settings" : "カレンダー設定",
     "At event start" : "イベント開始時",
@@ -190,19 +192,18 @@ OC.L10N.register(
     "Failed to save default calendar" : "デフォルトカレンダーの保存に失敗しました",
     "CalDAV link copied to clipboard." : "CalDAVリンクがクリップボードにコピーされました",
     "CalDAV link could not be copied to clipboard." : "CalDAVリンクをクリップボードにコピーできませんでした",
-    "Enable birthday calendar" : "誕生日カレンダーを有効にする",
-    "Show tasks in calendar" : "カレンダーにタスクを表示",
-    "Enable simplified editor" : "簡易エディターを有効にする",
-    "Limit the number of events displayed in the monthly view" : "月間ビューに表示されるイベント数を制限する",
-    "Show weekends" : "週末を表示する",
-    "Show week numbers" : "週番号を表示する",
-    "Time increments" : "時間の増加",
-    "Default calendar for incoming invitations" : "受信した招待状のデフォルトカレンダー",
-    "Default reminder" : "既定のリマインダー",
+    "General" : "一般",
+    "Personal availability settings" : "個人の稼働率設定",
     "Copy primary CalDAV address" : "通常のCalDAVアドレスをコピー",
     "Copy iOS/macOS CalDAV address" : "iOS/macOS用のCalDAVアドレスをコピー",
-    "Personal availability settings" : "個人の稼働率設定",
-    "Show keyboard shortcuts" : "キーボード ショートカット",
+    "Enable birthday calendar" : "誕生日カレンダーを有効にする",
+    "Show tasks in calendar" : "カレンダーにタスクを表示",
+    "Show weekends" : "週末を表示する",
+    "Show week numbers" : "週番号を表示する",
+    "Editing" : "編集中",
+    "Default calendar for incoming invitations" : "受信した招待状のデフォルトカレンダー",
+    "Default reminder" : "既定のリマインダー",
+    "Keyboard shortcuts" : "キーボードショートカット",
     "Appointment schedule successfully created" : "予約スケジュールの作成に成功しました",
     "Appointment schedule successfully updated" : "予約スケジュールの更新に成功しました",
     "_{duration} minute_::_{duration} minutes_" : ["{duration}分"],
@@ -253,7 +254,6 @@ OC.L10N.register(
     "Please share anything that will help prepare for our meeting" : "会議の準備に役立つことがあれば教えてください。",
     "Could not book the appointment. Please try again later or contact the organizer." : "予約できませんでした。後でもう一度試してみるか、主催者に連絡してください。",
     "Back" : "戻る",
-    "Create a new conversation" : "新しい会話を作成する",
     "Select conversation" : "会話を選択",
     "on" : "曜日",
     "at" : "で",
@@ -393,6 +393,10 @@ OC.L10N.register(
     "Update this occurrence" : "この出来事を更新する",
     "Public calendar does not exist" : "公開カレンダーは存在しません",
     "Maybe the share was deleted or has expired?" : "共有が削除されたか、期限切れの可能性があります",
+    "Yes" : "はい",
+    "No" : "いいえ",
+    "Maybe" : "たぶん",
+    "Create" : "作成",
     "from {formattedDate}" : "{formattedDate}から",
     "to {formattedDate}" : "{formattedDate}まで",
     "on {formattedDate}" : "{formattedDate} にて",
@@ -416,7 +420,6 @@ OC.L10N.register(
     "No valid public calendars configured" : "有効な公開カレンダーが設定されていない",
     "Speak to the server administrator to resolve this issue." : "この問題を解決するには、サーバー管理者にご相談ください。",
     "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "公開祝祭日カレンダーは Thunderbird によって提供されています。カレンダーデータは {website} からダウンロードされます",
-    "These public calendars are suggested by the sever administrator. Calendar data will be downloaded from the respective website." : "これらの公開カレンダーは、サーバー管理者によって提供されます。カレンダーのデータはそれぞれのウェブサイトからダウンロードされます。",
     "By {authors}" : "{author} 記載",
     "Subscribed" : "購読",
     "Subscribe" : "購読",
@@ -451,6 +454,11 @@ OC.L10N.register(
     "_Attachment requires shared access_::_Attachments requiring shared access_" : ["添付ファイルには共有アクセスが必要です"],
     "Untitled event" : "無題のイベント",
     "Close" : "閉じる",
+    "Selected" : "選択済み",
+    "Title" : "タイトル",
+    "30 min" : "30分",
+    "Participants" : "参加者",
+    "Submit" : "提出する",
     "Subscribe to {name}" : "{name} を購読する",
     "Export {name}" : "エクスポート {name}",
     "Anniversary" : "記念日",
@@ -543,12 +551,10 @@ OC.L10N.register(
     "This is an event reminder." : "これはイベントのリマインダーです。",
     "Appointment not found" : "予定が見つかりません",
     "User not found" : "ユーザーが見つかりません",
-    "Reminder" : "リマインダー",
-    "+ Add reminder" : "+ リマインダーを追加",
-    "Select automatic slot" : "自動スロット選択",
-    "with" : "とともに",
-    "Available times:" : "利用可能な時間帯:",
-    "Suggestions" : "提案",
-    "Details" : "詳細"
+    "Shortcut overview" : "概要",
+    "Enable simplified editor" : "簡易エディターを有効にする",
+    "Limit the number of events displayed in the monthly view" : "月間ビューに表示されるイベント数を制限する",
+    "Time increments" : "時間の増加",
+    "Show keyboard shortcuts" : "キーボード ショートカット"
 },
 "nplurals=1; plural=0;");
