@@ -179,24 +179,22 @@ OC.L10N.register(
     "Save edited event" : "Save edited event",
     "Delete edited event" : "Delete edited event",
     "Duplicate event" : "Duplicate event",
-    "Shortcut overview" : "Shortcut overview",
     "or" : "or",
     "Calendar settings" : "Calendar settings",
     "No reminder" : "No reminder",
     "CalDAV link copied to clipboard." : "CalDAV link copied to clipboard.",
     "CalDAV link could not be copied to clipboard." : "CalDAV link could not be copied to clipboard.",
-    "Enable birthday calendar" : "Enable birthday calendar",
-    "Show tasks in calendar" : "Show tasks in calendar",
-    "Enable simplified editor" : "Enable simplified editor",
-    "Limit the number of events displayed in the monthly view" : "Limit the number of events displayed in the monthly view",
-    "Show weekends" : "Show weekends",
-    "Show week numbers" : "Show week numbers",
-    "Time increments" : "Time increments",
-    "Default reminder" : "Default reminder",
+    "General" : "General",
+    "Personal availability settings" : "Personal availability settings",
     "Copy primary CalDAV address" : "Copy primary CalDAV address",
     "Copy iOS/macOS CalDAV address" : "Copy iOS/macOS CalDAV address",
-    "Personal availability settings" : "Personal availability settings",
-    "Show keyboard shortcuts" : "Show keyboard shortcuts",
+    "Enable birthday calendar" : "Enable birthday calendar",
+    "Show tasks in calendar" : "Show tasks in calendar",
+    "Show weekends" : "Show weekends",
+    "Show week numbers" : "Show week numbers",
+    "Editing" : "Editing",
+    "Default reminder" : "Default reminder",
+    "Keyboard shortcuts" : "Keyboard shortcuts",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minute","{duration} minutes"],
     "0 minutes" : "0 minutes",
     "_{duration} hour_::_{duration} hours_" : ["{duration} hour","{duration} hours"],
@@ -363,6 +361,8 @@ OC.L10N.register(
     "Public calendar does not exist" : "Public calendar does not exist",
     "Maybe the share was deleted or has expired?" : "Maybe the share was deleted or has expired?",
     "Remove participant" : "Remove participant",
+    "Yes" : "კი",
+    "No" : "არა",
     "Create" : "Create",
     "from {formattedDate}" : "from {formattedDate}",
     "to {formattedDate}" : "to {formattedDate}",
@@ -419,7 +419,9 @@ OC.L10N.register(
     "Untitled event" : "Untitled event",
     "Close" : "Close",
     "Selected" : "Selected",
+    "30 min" : "30 წთ",
     "Participants" : "Participants",
+    "Submit" : "Submit",
     "Subscribe to {name}" : "Subscribe to {name}",
     "Export {name}" : "Export {name}",
     "Anniversary" : "Anniversary",
@@ -509,6 +511,11 @@ OC.L10N.register(
     "Imported {filename}" : "Imported {filename}",
     "This is an event reminder." : "This is an event reminder.",
     "Appointment not found" : "Appointment not found",
-    "User not found" : "User not found"
+    "User not found" : "User not found",
+    "Shortcut overview" : "Shortcut overview",
+    "Enable simplified editor" : "Enable simplified editor",
+    "Limit the number of events displayed in the monthly view" : "Limit the number of events displayed in the monthly view",
+    "Time increments" : "Time increments",
+    "Show keyboard shortcuts" : "Show keyboard shortcuts"
 },
 "nplurals=2; plural=(n!=1);");
