@@ -22,22 +22,23 @@ OC.L10N.register(
     "Appointments" : "Plānotās tikšanās",
     "Schedule appointment \"%s\"" : " Ieplānot tikšanos \"%s\"",
     "Schedule an appointment" : "Ieplānot tikšanos",
-    "Prepare for %s" : "Sagatavojieties %s",
+    "Prepare for %s" : "Sagatavojies %s",
     "Follow up for %s" : "Seko līdzi %s",
-    "Your appointment \"%s\" with %s needs confirmation" : "Jūsu tikšanās \"%s\" ar %s nepieciešama apstiprināšana.",
+    "Your appointment \"%s\" with %s needs confirmation" : "Tavai tikšanās \"%s\" ar %s nepieciešama apstiprināšana.",
     "Dear %s, please confirm your booking" : " %s, lūgums apstiprināt savu rezervāciju",
     "Confirm" : "Apstiprināt",
     "This confirmation link expires in %s hours." : "Šī apstiprinājuma saites derīgums beigsies pēc %s stundām.",
     "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Ja tomēr ir vēlme atcelt tikšanos, lūgums sazināties ar rīkotāju, atbildot uz šo e-pasta ziņojumu vai apmeklējot tā profilu.",
-    "Your appointment \"%s\" with %s has been accepted" : "Jūsu plānotā tikšanās \"%s\" ar %s ir apstiprināta.",
-    "Dear %s, your booking has been accepted." : " %s, Jūsu rezervācija ir apstiprināta.",
+    "Your appointment \"%s\" with %s has been accepted" : "Tava paredzētā  tikšanās \"%s\" ar %s tika apstiprināta.",
+    "Dear %s, your booking has been accepted." : " %s, Tava rezervācija tika apstiprināta.",
     "Appointment for:" : "Plānota tikšanās:",
     "Date:" : "Datums:",
-    "You will receive a link with the confirmation email" : "Jūs saņemsiet saiti apstiprinājuma e-pastā.",
+    "You will receive a link with the confirmation email" : "Tu saņemsi saiti apstiprinājuma e-pasta ziņojumā",
     "Where:" : "Kur:",
     "Comment:" : "Piebilde:",
     "You have a new appointment booking \"%s\" from %s" : "Jums ir jauna tikšanās rezervācija \"%s\" no %s",
     "Dear %s, %s (%s) booked an appointment with you." : " %s, %s (%s) rezervēja tikšanos ar Jums.",
+    "Location:" : "Atrašanās vieta:",
     "A Calendar app for Nextcloud" : "Nextcloud kalendāra lietotne",
     "Previous day" : "Iepriekšējā diena",
     "Previous week" : "Iepriekšējā nedēļa",
@@ -72,7 +73,7 @@ OC.L10N.register(
     "Edit and share calendar" : "Labot un koplietot kalendāru",
     "Edit calendar" : "Labot kalendāru",
     "An error occurred, unable to create the calendar." : "Atgadījās kļūda, nevar izveidot kalendāru.",
-    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Lūdzu, ievadiet derīgu saiti (kas sākas ar http://, https://, webcal:// vai webcals://)",
+    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Lūgums ievadīt derīgu saiti (sākas ar http://, https://, webcal:// vai webcals://)",
     "Calendars" : "Kalendāri",
     "Add new" : "Pievienot jaunu",
     "New calendar" : "Jauns kalendārs",
@@ -136,6 +137,7 @@ OC.L10N.register(
     "Share calendar" : "Koplietot kalendāru",
     "Unshare from me" : "Atcelt koplietošanu no manis",
     "Save" : "Saglabāt",
+    "View" : "Skats",
     "Import calendars" : "Ievietot kalendārus",
     "Please select a calendar to import into …" : "Lūgums atlasīt kalendāru, kurā ievietot ...",
     "Filename" : "Datnes nosaukums",
@@ -143,7 +145,7 @@ OC.L10N.register(
     "Cancel" : "Atcelt",
     "Select the default location for attachments" : "Atlasīt pielikumu noklusējuma atrašanās vietu",
     "Invalid location selected" : "Ir izvēlēta nederīga atrašanās vieta ",
-    "Attachments folder successfully saved." : "Pielikumu mape veiksmīgi saglabāta.",
+    "Attachments folder successfully saved." : "Pielikumu mape saglabāta sekmīgi.",
     "Error on saving attachments folder." : "Kļūda saglabājot pielikumu mapi.",
     "Default attachments location" : "Pielikumu noklusējuma atrašanās vietas",
     "No valid files found, aborting import" : "Nav atrastas derīgas datnes, ievietošana tiek pārtraukta.",
@@ -152,6 +154,7 @@ OC.L10N.register(
     "Automatic" : "Automātisks",
     "Automatic ({detected})" : "Automātiska ({detected})",
     "New setting was not saved successfully." : "Jauna iestatījuma saglabāšana neizdevās.",
+    "Timezone" : "Laika josla",
     "Navigation" : "Navigācija",
     "Previous period" : "Iepriekšējais laika posms",
     "Next period" : "Nākamais periods",
@@ -169,24 +172,23 @@ OC.L10N.register(
     "Save edited event" : "Saglabāt laboto notikumu",
     "Delete edited event" : "Izdzēst laboto notikumu",
     "Duplicate event" : "Pavairot notikumu",
-    "Shortcut overview" : "Īsceļu pārskats",
     "or" : "vai",
     "Calendar settings" : "Kalendāra iestatījumi",
     "No reminder" : "Nav atgādinājuma",
     "Failed to save default calendar" : "Neizdevās saglabāt noklusējuma kalendāru",
     "CalDAV link copied to clipboard." : "Kalendāra saite ievietota starpliktuvē.",
     "CalDAV link could not be copied to clipboard." : "Kalendāra saiti neizdevās ievietot starpliktuvē.",
-    "Enable birthday calendar" : "Iespējot dzimšanas dienas kalendāru",
-    "Show tasks in calendar" : "Rādīt uzdevumus kalendārā",
-    "Enable simplified editor" : "Iespējot vienkāršoto redaktoru",
-    "Limit the number of events displayed in the monthly view" : "Ierobežot notikumu skaitu, kas tiek parādīti mēneša skatā",
-    "Show weekends" : "Rādīt nedēļas nogales",
-    "Show week numbers" : "Rādīt nedēļu numurus",
-    "Default reminder" : "Noklusējuma atgādinājums",
+    "General" : "Vispārīgi",
+    "Personal availability settings" : "Personiskās pieejamības iestatījumi",
     "Copy primary CalDAV address" : "Ievietot starpliktuvē galveno CalDAV adresi",
     "Copy iOS/macOS CalDAV address" : "Kopēt IOS/macOS CalDAV adresi",
-    "Personal availability settings" : "Personiskās pieejamības iestatījumi",
-    "Show keyboard shortcuts" : "Rādīt tastatūras saīsnes taustiņus",
+    "Enable birthday calendar" : "Iespējot dzimšanas dienas kalendāru",
+    "Show tasks in calendar" : "Rādīt uzdevumus kalendārā",
+    "Show weekends" : "Rādīt nedēļas nogales",
+    "Show week numbers" : "Rādīt nedēļu numurus",
+    "Editing" : "Labošana",
+    "Default reminder" : "Noklusējuma atgādinājums",
+    "Keyboard shortcuts" : "Tastatūras saīsnes",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minūšu","{duration} minūte","{duration} minūtes"],
     "0 minutes" : "0 minūtes",
     "_{duration} hour_::_{duration} hours_" : ["{duration} stundu","{duration} stunda","{duration} stundas"],
@@ -203,7 +205,7 @@ OC.L10N.register(
     "Visibility" : "Redzamība",
     "Duration" : "Ilgums",
     "Additional calendars to check for conflicts" : "Papildu kalendāri nesaderību pārbaudīšanai",
-    "Pick time ranges where appointments are allowed" : "Izvēlieties laika intervālus, kurās ir atļautas tikšanās.",
+    "Pick time ranges where appointments are allowed" : "Jāizvēlas laika apgabali, kuros ir atļautas tikšanās",
     "to" : "kam",
     "No times set" : "Laiks nav noteikts",
     "Add" : "Pievienot",
@@ -222,8 +224,8 @@ OC.L10N.register(
     "Please confirm your reservation" : "Lūgums apstiprināt savu rezervāciju",
     "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Mēs nosūtījām e-pasta ziņojumu ar informāciju. Lūgums apstiprināt savu tikšanos ar e-pasta ziņojumā esošo saiti. Šo lapu tagad var aizvērt.",
     "Your name" : "Tavs vārds",
-    "Your email address" : "Jūsu e-pasta adrese",
-    "Please share anything that will help prepare for our meeting" : "Lūdzu, dalieties ar visu, kas palīdzēs sagatavoties mūsu sanāksmei",
+    "Your email address" : "Tava e-pasta adrese",
+    "Please share anything that will help prepare for our meeting" : "Lūgums koplietot visu, kas palīdzēs sagatavoties mūsu sanāksmei",
     "Could not book the appointment. Please try again later or contact the organizer." : "Neizdevās pieteikt tikšanos. Lūgums vēlāk mēģināt vēlreiz vai sazināties ar rīkotāju.",
     "Successfully added Talk conversation link to location." : "Talk sarunas saite sekmīgi pievienota atrašanās vietai.",
     "Successfully added Talk conversation link to description." : "Talk sarunas saite sekmīgi pievienota aprakstam.",
@@ -279,11 +281,11 @@ OC.L10N.register(
     "Busy" : "Aizņemts",
     "Unknown" : "Nezināms",
     "Find a time" : "Atrast laiku",
-    "The invitation has been accepted successfully." : "Uzaicinājums ir veiksmīgi apstiprināts.",
+    "The invitation has been accepted successfully." : "Uzaicinājums tika sekmīgi apstiprināts.",
     "Failed to accept the invitation." : "Neizdevās apstiprināt uzaicinājumu.",
-    "The invitation has been declined successfully." : "Uzaicinājums ir veiksmīgi noraidīts.",
+    "The invitation has been declined successfully." : "Uzaicinājums tika sekmīgi noraidīts.",
     "Failed to decline the invitation." : "Neizdevās atteikt uzaicinājumu.",
-    "Your participation has been marked as tentative." : "Jūsu piedalīšanās ir atzīmēta kā nenoteikta.",
+    "Your participation has been marked as tentative." : "Tava piedalīšanās tika atzīmēta kā nenoteikta.",
     "Failed to set the participation status to tentative." : "Neizdevās iestatīt dalības stāvokli kā nenoteiktu.",
     "Accept" : "Pieņemt",
     "Decline" : "Noraidīt",
@@ -339,17 +341,19 @@ OC.L10N.register(
     "Update this occurrence" : "Atjaunināt šo notikumu",
     "Public calendar does not exist" : "Publiskais kalendārs nepastāv",
     "Maybe the share was deleted or has expired?" : "Varbūt kopīgojums tika izdzēsts, vai arī ir beidzies tā derīgums?",
+    "Yes" : "Jā",
+    "No" : "Nē",
     "from {formattedDate}" : "no {formattedDate}",
     "to {formattedDate}" : "līdz {formattedDate}",
     "from {formattedDate} at {formattedTime}" : "no {formattedDate} plkst. {formattedTime}",
     "to {formattedDate} at {formattedTime}" : "līdz {formattedDate} plkst. {formattedTime}",
     "on {formattedDate} at {formattedTime}" : "{formattedDate} plkst. {formattedTime}",
     "{formattedDate} at {formattedTime}" : "{formattedDate} plkst. {formattedTime}",
-    "Please enter a valid date" : "Lūdzu ievadiet derīgu datumu",
-    "Please enter a valid date and time" : "Lūdzu ievadiet derīgu datumu un laiku",
-    "Please select a time zone:" : "Lūdzu, izvēlieties laika joslu:",
-    "Pick a time" : "Izvēlieties laiku",
-    "Pick a date" : "Izvēlieties datumu",
+    "Please enter a valid date" : "Lūgums ievadīt derīgu datumu",
+    "Please enter a valid date and time" : "Lūgums ievadīt derīgu datumu un laiku",
+    "Please select a time zone:" : "Lūgums atlasīt laika joslu:",
+    "Pick a time" : "Izvēlēties laiku",
+    "Pick a date" : "Izvēlēties datumu",
     "Type to search time zone" : "Rakstīt, lai meklētu laika zonu",
     "Global" : "Globāls",
     "Holidays in {region}" : "Brīvdienas {region}",
@@ -358,13 +362,13 @@ OC.L10N.register(
     "Speak to the server administrator to resolve this issue." : "Jāsazinās ar servera pārvaldītāju, lai atrisinātu šo sarežģījumu.",
     "Subscribed" : "Abonēts",
     "Subscribe" : "Abonēt",
-    "Select slot" : "Izvēlieties laiku",
+    "Select slot" : "Atlasīt laikspraugu",
     "The slot for your appointment has been confirmed" : "Vieta paredzētajam notikumam tika apstiprināta",
     "Appointment Details:" : "Informācija par paredzēto tikšanos:",
     "Time:" : "Laiks:",
     "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Paldies! Rezervācija no {startDate} līdz {endDate} tika apstiprināta.",
     "Book another appointment:" : "Rezervēt vēl vienu plānotu tikšanos",
-    "Book an appointment with {name}" : "Rezervējiet plānotu tikšanos ar {name}",
+    "Book an appointment with {name}" : "Pieteikt tikšanos ar {name}",
     "Personal" : "Personīgs",
     "Edit event" : "Labot notikumu",
     "Event does not exist" : "Notikums nepastāv",
@@ -377,6 +381,10 @@ OC.L10N.register(
     "_User requires access to your file_::_Users require access to your file_" : ["Lietotāji pieprasa piekļuvi Tavai datnei","Lietotājs pieprasa piekļuvi Tavai datnei","Lietotāji pieprasa piekļuvi Tavai datnei"],
     "Untitled event" : "Nenosaukts notikums",
     "Close" : "Aizvērt",
+    "Selected" : "Atlasītās",
+    "Title" : "Virsraksts",
+    "Participants" : "Dalībnieki",
+    "Submit" : "Iesniegt",
     "Subscribe to {name}" : "Abonēt {name}",
     "Export {name}" : "Izgūt {name}",
     "Anniversary" : "Gadadiena",
@@ -457,9 +465,9 @@ OC.L10N.register(
     "This is an event reminder." : "Šis ir notikuma atgādinājums.",
     "Appointment not found" : "Tikšanās nav atrasta",
     "User not found" : "Lietotājs nav atrasts",
-    "Reminder" : "Atgādinājums",
-    "+ Add reminder" : "Pievienot atgādinājumu",
-    "Suggestions" : "Ieteikumi",
-    "Details" : "Informācija"
+    "Shortcut overview" : "Īsceļu pārskats",
+    "Enable simplified editor" : "Iespējot vienkāršoto redaktoru",
+    "Limit the number of events displayed in the monthly view" : "Ierobežot notikumu skaitu, kas tiek parādīti mēneša skatā",
+    "Show keyboard shortcuts" : "Rādīt tastatūras saīsnes taustiņus"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
