@@ -28,6 +28,7 @@ OC.L10N.register(
     "Your appointment \"%s\" with %s needs confirmation" : "Потребна е потврда за состанокот \"%s\" со %s",
     "Dear %s, please confirm your booking" : "Поритуван/а %s, ве молиме потврдете ја вашата резервација",
     "Confirm" : "Потврди",
+    "Appointment with:" : "Состанок со:",
     "Description:" : "Опис:",
     "This confirmation link expires in %s hours." : "Овој линк за потврда истекува за %s часа.",
     "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "И покрај се, ако сакате да го откажете состанокот, контактирајте го организаторот со тоа што ќе одговорите на оваа е-пошта или посетете го неговиот профил",
@@ -40,6 +41,14 @@ OC.L10N.register(
     "Comment:" : "Коментар:",
     "You have a new appointment booking \"%s\" from %s" : "Имате нов закажан состанок \"%s\" од %s",
     "Dear %s, %s (%s) booked an appointment with you." : "Почитуван/а %s, %s (%s) закажа состанок со вас.",
+    "%s has proposed a meeting" : "%s предложи состанок",
+    "%s has updated a proposed meeting" : "%s го ажурираше предложениот состанок",
+    "%s has canceled a proposed meeting" : "%s го откажа предложениот состанок",
+    "Location:" : "Локација:",
+    "Duration:" : "Времетраење:",
+    "%1$s from %2$s to %3$s" : "%1$s од %2$s до %3$s",
+    "Dates:" : "Датуми:",
+    "Respond" : "Одговори",
     "A Calendar app for Nextcloud" : "Календар апликација за Nextcloud",
     "Previous day" : "Предходен ден",
     "Previous week" : "Предходна недела",
@@ -63,6 +72,7 @@ OC.L10N.register(
     "Copy link" : "Копирај линк",
     "Edit" : "Уреди",
     "Delete" : "Избриши",
+    "Appointment schedules" : "Распоред на состаноци",
     "Create new" : "Креирај нова",
     "Disable calendar \"{calendar}\"" : "Оневозможи календар \"{calendar}\"",
     "Disable untitled calendar" : "Оневозможи неименуван календар",
@@ -86,6 +96,7 @@ OC.L10N.register(
     "New subscription from link (read-only)" : "Нова претплата од линк (само за читање)",
     "Creating subscription …" : "Креирање претплата  …",
     "Add public holiday calendar" : "Додади календар со државни празници",
+    "Add custom public calendar" : "Додади сопствен јавен календар",
     "Calendar link copied to clipboard." : "Линк до календарот е копиран во клипборд.",
     "Calendar link could not be copied to clipboard." : "Линк до календарот неможе да се копира во клипборд.",
     "Copy subscription link" : "Копирај линк за претплата",
@@ -109,6 +120,7 @@ OC.L10N.register(
     "Delete permanently" : "Избриши",
     "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Работите од корпата за отпадоци ќе бидат избришани после {numDays} ден","Работите од корпата за отпадоци ќе бидат избришани после  {numDays} дена"],
     "Could not update calendar order." : "Неможе да се ажурира редоследот на календарите.",
+    "Shared calendars" : "Споделени календари",
     "Deck" : "Deck",
     "Hidden" : "Сокриен",
     "Internal link" : "Внатрешен линк",
@@ -130,6 +142,7 @@ OC.L10N.register(
     "Could not copy code" : "Неможе да се копира кодот",
     "Delete share link" : "Избриши го линкот за споделување",
     "Deleting share link …" : "Се брише линкот за споделување …",
+    "{teamDisplayName} (Team)" : "{teamDisplayName} (Тим)",
     "An error occurred while unsharing the calendar." : "Настана грешка при откажување на споделување на календар.",
     "An error occurred, unable to change the permission of the share." : "Настана грешка, неможе да се променат дозволите за споделување.",
     "can edit" : "може да се измени",
@@ -138,9 +151,18 @@ OC.L10N.register(
     "No users or groups" : "Нема корисници или групи",
     "Failed to save calendar name and color" : "Неуспешно зачувување на име на календар и боја",
     "Calendar name …" : "Име на календар ...",
+    "Never show me as busy (set this calendar to transparent)" : "Никогаш не ме прикажувај зафатен (постави го овој календар транспарентен)",
     "Share calendar" : "Сподели календар",
     "Unshare from me" : "Не споделувај со мене",
     "Save" : "Зачувај",
+    "No title" : "Нема наслов",
+    "Are you sure you want to delete \"{title}\"?" : "Дали сте сигурни дека сакате да го избришете \"{title}\"?",
+    "Deleting proposal \"{title}\"" : "Бришење на предлогот \"{title}\"",
+    "Successfully deleted proposal" : "Успешно бришење на предлог",
+    "Failed to delete proposal" : "Неуспешно бришење на предлог",
+    "Meeting proposals" : "Предлози за состаноци",
+    "No active meeting proposals" : "Нема активен предлог за состаноци",
+    "View" : "Поглед",
     "Import calendars" : "Увези календари",
     "Please select a calendar to import into …" : "Изберете календар за да направите увоз во него …",
     "Filename" : "Име на датотека",
@@ -148,6 +170,7 @@ OC.L10N.register(
     "Cancel" : "Откажи",
     "_Import calendar_::_Import calendars_" : ["Увези календар","Увези календари"],
     "Select the default location for attachments" : "Избери стандардна локација за прилози",
+    "Pick" : "Избери",
     "Invalid location selected" : "Избрана невалидна локација",
     "Attachments folder successfully saved." : "Папката за прилози е успешно зачувана.",
     "Error on saving attachments folder." : "Грешка при зачувување на папка за прилози.",
@@ -175,25 +198,27 @@ OC.L10N.register(
     "Close editor" : "Затвори го уредникот",
     "Save edited event" : "Зачувај го изменетиот настан",
     "Delete edited event" : "Избриши го изменетиот настан",
-    "Duplicate event" : "Дуплицирај настај",
-    "Shortcut overview" : "Преглед на кратенки преку тастатура",
+    "Duplicate event" : "Дуплирај настај",
     "or" : "или",
     "Calendar settings" : "Параметри за календар",
+    "At event start" : "На почетокот на настанот",
     "No reminder" : "Нема потсетник",
+    "Failed to save default calendar" : "Неуспешно зачувување на стандарден календар",
     "CalDAV link copied to clipboard." : "CalDAV линкот е копиран.",
     "CalDAV link could not be copied to clipboard." : "CalDAV линкот неможе да биде копиран.",
-    "Enable birthday calendar" : "Овозможи календар со родендени",
-    "Show tasks in calendar" : "Прикажи ги задачите во календарнот",
-    "Enable simplified editor" : "Овозможи поедноставен уредувач",
-    "Limit the number of events displayed in the monthly view" : "Ограничи број на настани прикажани во месечниот преглед",
-    "Show weekends" : "Прикажи викенди",
-    "Show week numbers" : "Прикажи броеви на неделите",
-    "Time increments" : "Временско зголемување",
-    "Default reminder" : "Стандарден потсетник",
+    "General" : "Општо",
+    "Personal availability settings" : "Параметри за лична достапност",
     "Copy primary CalDAV address" : "Копирај примарна CalDAV адреса",
     "Copy iOS/macOS CalDAV address" : "Копирај iOS/macOS CalDAV адреса",
-    "Personal availability settings" : "Параметри за лична достапност",
-    "Show keyboard shortcuts" : "Прикажи кратенки преку тастатура",
+    "Enable birthday calendar" : "Овозможи календар со родендени",
+    "Show tasks in calendar" : "Прикажи ги задачите во календарнот",
+    "Show weekends" : "Прикажи викенди",
+    "Show week numbers" : "Прикажи броеви на неделите",
+    "Default calendar for incoming invitations" : "Стандарден календар за дојдовни покани",
+    "Default reminder" : "Стандарден потсетник",
+    "Keyboard shortcuts" : "Кратенки преку тастатура",
+    "Appointment schedule successfully created" : "Распоред за состаноци е успешно креиран",
+    "Appointment schedule successfully updated" : "Распоред за состаноци е успешно ажуриран",
     "_{duration} minute_::_{duration} minutes_" : ["1 минута","{duration} минути"],
     "0 minutes" : "0 минути",
     "_{duration} hour_::_{duration} hours_" : ["1 час","{duration} часа"],
@@ -204,6 +229,9 @@ OC.L10N.register(
     "To configure appointments, add your email address in personal settings." : "За да ги конфигурирате состаноците, додајте ја вашата адреса за е-пошта во личните поставки.",
     "Public – shown on the profile page" : "Јавен - Прикажи на профилната страница",
     "Private – only accessible via secret link" : "Приватен - пристап само со безбедносен линк",
+    "Appointment schedule saved" : "Распоред за состаноци е зачуван",
+    "Create appointment schedule" : "Креирај распоред за состаноци",
+    "Edit appointment schedule" : "Уреди распоред за состаноци",
     "Update" : "Ажурирај",
     "Appointment name" : "Име на состанокот",
     "Location" : "Локација",
@@ -241,11 +269,10 @@ OC.L10N.register(
     "Please share anything that will help prepare for our meeting" : "Ве молиме споделете сè што ќе помогне да се подготвиме за нашиот состанок",
     "Could not book the appointment. Please try again later or contact the organizer." : "Не може да се резервира термин. Обидете се повторно подоцна или контактирајте со организаторот.",
     "Back" : "Назад",
-    "Create a new conversation" : "Креирај нов разговор",
+    "Book appointment" : "Резервирај состанок",
     "Select conversation" : "Избери разговор",
     "on" : "во",
     "at" : "во",
-    "Reminder" : "Потсетник",
     "before at" : "пред",
     "Notification" : "Известување",
     "Email" : "Е-пошта",
@@ -256,7 +283,6 @@ OC.L10N.register(
     "Edit time" : "Удери време",
     "Save time" : "Зачувај време",
     "Remove reminder" : "Отстрани потсетник",
-    "+ Add reminder" : "+ Додади потсетник",
     "Add reminder" : "Додади потсетник",
     "seconds" : "секунди",
     "minutes" : "минути",
@@ -266,10 +292,13 @@ OC.L10N.register(
     "Choose a file to add as attachment" : "Избери датотека за да додадете прилог",
     "Choose a file to share as a link" : "Избери датотека за да се сподели како линк",
     "Attachment {name} already exist!" : "Прилогот {name} веќе постои!",
+    "Could not upload attachment(s)" : "Неможе да се прикачи прилог",
+    "Proceed" : "Продолжи",
     "No attachments" : "Нема прилози",
     "Add from Files" : "Додади од датотеките",
     "Upload from device" : "Прикачи од уред",
     "Delete file" : "Избриши датотека",
+    "Confirmation" : "Потврда",
     "_{count} attachment_::_{count} attachments_" : ["{count} прилог","{count} прилози"],
     "Suggested" : "Предложено",
     "Available" : "Достапно",
@@ -280,16 +309,36 @@ OC.L10N.register(
     "Not available" : "Недостапно",
     "Invitation declined" : "Поканата е одбиена",
     "Declined {organizerName}'s invitation" : "Одбиена е покана од {organizerName}",
+    "Availability will be checked" : "Достапноста ќе биде проверена",
+    "Invitation will be sent" : "Поканата ќе се испрати",
+    "Failed to check availability" : "Неуспешно проверување на достапноста",
+    "Failed to deliver invitation" : "Неуспешно доставување на поканата",
+    "Awaiting response" : "Чекање на одговор",
     "Checking availability" : "Проверување на достапност",
     "Has not responded to {organizerName}'s invitation yet" : "Сè уште не одговорил на поканата на {organizerName}",
+    "Suggested times" : "Предложено време",
+    "chairperson" : "претседавач",
+    "required participant" : "задолжителен учесник",
+    "non-participant" : "не-учесник",
+    "optional participant" : "незадолжителен учесник",
     "{organizer} (organizer)" : "{organizer} (organizer)",
+    "{attendee} ({role})" : "{attendee} ({role})",
+    "Availability of attendees, resources and rooms" : "Достапност на присутните, ресурси и соби",
+    "Suggestion accepted" : "Сугестијата е прифатена",
+    "Previous date" : "Предходен датум",
+    "Next date" : "Следен датум",
+    "Legend" : "Легенда",
+    "Out of office" : "Надвор од канцеларија",
+    "Attendees:" : "Присутни:",
+    "Done" : "Готово",
+    "Search room" : "Пребарај соба",
+    "Room name" : "Име на соба",
+    "Check room availability" : "Провери достапност на соба",
     "Free" : "Слободен",
     "Busy (tentative)" : "Зафатен (привремено)",
     "Busy" : "Зафатен",
-    "Out of office" : "Надвор од канцеларија",
     "Unknown" : "Непознат",
-    "Availability of attendees, resources and rooms" : "Достапност на присутните, ресурси и соби",
-    "Done" : "Готово",
+    "Find a time" : "Пронајди термин",
     "The invitation has been accepted successfully." : "Поканата е успешно прифатена.",
     "Failed to accept the invitation." : "Неуспешно прифаќање на поканата.",
     "The invitation has been declined successfully." : "Поканата е успешно одбиена.",
@@ -300,26 +349,32 @@ OC.L10N.register(
     "Decline" : "Одбиј",
     "Tentative" : "Пробно",
     "No attendees yet" : "Сè уште нема присутни",
+    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} поканети, {confirmedCount} потврдени",
     "Successfully appended link to talk room to location." : "Успешно е додадена врска од собата за разговор во локација.",
     "Successfully appended link to talk room to description." : "Успешно додаден линк од собата за разговор во описот.",
     "Error creating Talk room" : "Грешка при креирање на соба за разговор",
     "Attendees" : "Присутни",
+    "_%n more guest_::_%n more guests_" : ["%n гостин","%n други гости"],
     "Remove group" : "Отстрани група",
     "Remove attendee" : "Откажи присутност",
+    "Request reply" : "Побарај одговор",
     "Chairperson" : "Претседавач",
     "Required participant" : "Задолжителен учесник",
     "Optional participant" : "Незадолжителен учесник",
     "Non-participant" : "Не-учесник",
+    "_%n member_::_%n members_" : ["%n член","%n членови"],
+    "Search for emails, users, contacts, contact groups or teams" : "Пребарувај за е-пошти, корисници, контакти, групи или тимови",
     "No match found" : "Нема совпаѓања",
     "(organizer)" : "(organizer)",
+    "Make {label} the organizer" : "Направи го {label} организатор",
     "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "За да испратите покана и да можете да добивате одговори,  [linkopen]додадете ја вашата е-пошта адреса во личните податоци на сметката[linkclose].",
     "Remove color" : "Отстрани боја",
     "Event title" : "Наслов на настанот",
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "Не може да се менуваат целодневните параметри за настани што се дел од множество за повторување.",
     "From" : "Од",
     "To" : "До",
-    "All day" : "Цели денови",
     "Repeat" : "Повтори",
+    "Repeat event" : "Повтори настан",
     "_time_::_times_" : ["еднаш","пати"],
     "never" : "никогаш",
     "on date" : "на датум",
@@ -336,12 +391,13 @@ OC.L10N.register(
     "_week_::_weeks_" : ["недела","недели"],
     "_month_::_months_" : ["месец","месеци"],
     "_year_::_years_" : ["година","години"],
+    "On specific day" : "На одреден ден",
     "weekday" : "работен ден",
     "weekend day" : "ден од викенд",
     "Does not repeat" : "Не повторувај",
     "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Дефиницијата за повторување на овој настан не е целосно поддржана од Nextcloud. Ако ги уредите опциите за повторување, одредени повторувања може да се изгубат.",
     "No rooms or resources yet" : "Сè уште нема простории или ресурси",
-    "Suggestions" : "Предлози",
+    "Resources" : "Ресурси",
     "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["1 седиште","{seatingCapacity} седишта"],
     "Add resource" : "Додади ресурс",
     "Has a projector" : "Има проектор",
@@ -351,15 +407,25 @@ OC.L10N.register(
     "Search for resources or rooms" : "Пребарајте ресурси или простории",
     "available" : "достапно",
     "unavailable" : "недостапно",
+    "Show all rooms" : "Прикажи ги сите соби",
     "Projector" : "Проектор",
     "Whiteboard" : "Табла",
     "Room type" : "Вид на соба",
     "Any" : "Било кој",
     "Minimum seating capacity" : "Минимален капацитет за седење",
+    "More details" : "Повеќе детали",
     "Update this and all future" : "Ажурирајте го овој и сите во иднина",
     "Update this occurrence" : "Ажурирајте ја оваа можност",
     "Public calendar does not exist" : "Јавниот календар не постои",
     "Maybe the share was deleted or has expired?" : "Можеби споделувањето е избришано ики рокот му е поминат?",
+    "Remove date" : "Избриши датум",
+    "Attendance required" : "Потребно е присуство",
+    "Attendance optional" : "Присуството е опционално",
+    "Remove participant" : "Одстрани учесник",
+    "Yes" : "Да",
+    "No" : "Не",
+    "Maybe" : "Можеби",
+    "Create" : "Креирај",
     "from {formattedDate}" : "од {formattedDate}",
     "to {formattedDate}" : "до {formattedDate}",
     "on {formattedDate}" : "на {formattedDate}",
@@ -369,13 +435,17 @@ OC.L10N.register(
     "{formattedDate} at {formattedTime}" : "{formattedDate} во {formattedTime}",
     "Please enter a valid date" : "Внесете валиден датум",
     "Please enter a valid date and time" : "Внесете валиден датум и време",
+    "Select a time zone" : "Избери временска зона",
     "Please select a time zone:" : "Изберете временска зона:",
     "Pick a time" : "Избери време",
     "Pick a date" : "Избери датум",
     "Type to search time zone" : "Пребарај временски зони",
     "Global" : "Глобално",
     "Holidays in {region}" : "Празници во {region}",
+    "An error occurred, unable to read public calendars." : "Настана грешка, неможе да се прочитаат јавниоте календари.",
     "Public holiday calendars" : "Календар со државни празници",
+    "Public calendars" : "Јавни календари",
+    "Speak to the server administrator to resolve this issue." : "Разговарајте со администраторот на серверот за да го решите овој проблем.",
     "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Календарите за државни празници се обезбедени од Thunderbird. Податоците од календарот ќе се преземат од {website}",
     "By {authors}" : "Од {authors}",
     "Subscribed" : "Претплатени",
@@ -397,21 +467,54 @@ OC.L10N.register(
     "Personal" : "Лично",
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Автоматското откривање на временската зона утврди дека вашата временска зона е UTC.\nОва е најверојатно резултат на безбедносните мерки на вашиот веб прелистувач\nПоставете ја вашата временска зона во подесувањата за календарот.",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Вашата временска зона ({timezoneId}) не е пронајдена. Поставена е  (Координирано универзално време) UTC.\nПоставете ја вашата временска зона во подесувањата за календарот или пријавете го овој проблем.",
+    "Availability of {displayName}" : "Достапност на {displayName}",
+    "Edit event" : "Уреди го настанот",
     "Event does not exist" : "Настанот не постои",
     "Duplicate" : "Дуплирај",
     "Delete this occurrence" : "Избришете ја оваа можност",
     "Delete this and all future" : "Избришете го овој и сите во иднина",
-    "Details" : "Детали",
+    "All day" : "Цели денови",
     "Managing shared access" : "Управување со споделен пристап",
     "Deny access" : "Забрани пристап",
     "Invite" : "Покани",
-    "Resources" : "Ресурси",
     "_User requires access to your file_::_Users require access to your file_" : ["Корисник бара пристап до вашата датотека","Корисници бараат пристап до вашата датотека"],
     "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Прилог за кој е потребен пристап","Прилози за кои е потребен пристап"],
     "Untitled event" : "Неименуван настан",
     "Close" : "Затвори",
+    "Edit meeting proposal" : "Измени предлог за состанок",
+    "Create meeting proposal" : "Креирај предлог за состанок",
+    "Update meeting proposal" : "Ажурирај предлог за состанок",
+    "Saving proposal \"{title}\"" : "Зачуван предлог \"{title}\"",
+    "Successfully saved proposal" : "Успешно зачуван предлог",
+    "Failed to save proposal" : "Неуспешно зачувување на предлог",
+    "Create a meeting for \"{date}\"? This will create a calendar event with all participants." : "Креирај состанок за \"{date}\"? Ова ќе креира настан во календарот со сите учесници.",
+    "Creating meeting for {date}" : "Креирање состанок за {date}",
+    "Successfully created meeting for {date}" : "Успешно креиран состанок за {date}",
+    "Failed to create a meeting for {date}" : "Неуспешно креиран состанок за {date}",
+    "Please enter a valid duration in minutes." : "Внесете валидно времетраење во минути.",
+    "Selected" : "Избрани",
+    "No Description" : "Нема опис",
+    "No Location" : "Нема локација",
+    "Edit this meeting proposal" : "Измени го овој предлог за состанок",
+    "Delete this meeting proposal" : "Избриши го овој предлог за состанок",
+    "Title" : "Наслов",
+    "15 min" : "15 мин",
+    "30 min" : "30 мин",
+    "60 min" : "60 мин",
+    "90 min" : "90 мин",
+    "Participants" : "Учесници",
+    "Selected times" : "Избрани времиња",
+    "More days" : "Повеќе денови",
+    "Thank you for your response!" : "Благодариме на вашиот одговор.",
+    "Your vote has been recorded. Thank you for participating!" : "Вашиот глас е регистриран. Благодариме за учеството!",
+    "Unknown User" : "Непознат корисник",
+    "No Title" : "Нема наслов",
+    "No Duration" : "Нема времетраење",
+    "Select a different time zone" : "Избери различна временска зона",
+    "Submit" : "Испрати",
     "Subscribe to {name}" : "Претплатете се на {name}",
     "Export {name}" : "Извези {name}",
+    "Show availability" : "Прикажи достапност",
     "Anniversary" : "Годишнина",
     "Appointment" : "Состанок",
     "Business" : "Бизнис",
@@ -427,7 +530,7 @@ OC.L10N.register(
     "Travel" : "Патување",
     "Vacation" : "Одмор",
     "Midnight on the day the event starts" : "На полноќ на денот кога започнува настанот",
-    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["Еден ден пред настанот во {formattedHourMinute}","%n дена пред настанот во {formattedHourMinute}"],
+    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n ден пред настанот во {formattedHourMinute}","%n дена пред настанот во {formattedHourMinute}"],
     "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["Една недела пред настанот во {formattedHourMinute}","%n недели пред настанот во {formattedHourMinute}"],
     "on the day of the event at {formattedHourMinute}" : "На денот на настанот во {formattedHourMinute}",
     "at the event's start" : "на почетокот на настанот",
@@ -450,9 +553,10 @@ OC.L10N.register(
     "_on {weekday}_::_on {weekdays}_" : ["во {weekday}","во {weekdays}"],
     "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["на ден {dayOfMonthList}","на денови {dayOfMonthList}"],
     "on the {ordinalNumber} {byDaySet}" : "на {ordinalNumber} {byDaySet}",
+    "in {monthNames} on the {dayOfMonthList}" : "во {monthNames} на {dayOfMonthList}",
     "in {monthNames} on the {ordinalNumber} {byDaySet}" : "во {monthNames} на {ordinalNumber} {byDaySet}",
     "until {untilDate}" : "до {untilDate}",
-    "_%n time_::_%n times_" : ["уште еднаш","%n пати"],
+    "_%n time_::_%n times_" : ["%n пат","%n пати"],
     "second" : "втор",
     "third" : "трети",
     "fourth" : "четврти",
@@ -464,9 +568,13 @@ OC.L10N.register(
     "W" : "Н",
     "%n more" : "%n други",
     "No events to display" : "Нема настани за приказ",
+    "All participants declined" : "Сите учесници одбија",
+    "Please confirm your participation" : "Ве молиме потврдете го вашато присуство",
+    "You declined this event" : "Вие го одбивте овој настан",
     "_+%n more_::_+%n more_" : ["+%n друг","+%n други"],
     "No events" : "Нема настани",
     "Create a new event or change the visible time-range" : "Креирајте нов настан или променете го видливиот временски опсег",
+    "Failed to save event" : "Неуспешно зачувување на настанот",
     "It might have been deleted, or there was a typo in a link" : "Можеби е избришан или има грешка во врската",
     "It might have been deleted, or there was a typo in the link" : "Можеби е избришан или има грешка во врската",
     "Meeting room" : "Соба за состаноци",
@@ -479,6 +587,7 @@ OC.L10N.register(
     "When shared hide this event" : "Кога е споделен, сокриј го настанот",
     "The visibility of this event in shared calendars." : "Видливост на овој настан во споделен календар.",
     "Add a location" : "Додади локација",
+    "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "Додај опис\n\n- За што е овој состанок\n- Точки на дневен ред\n- Сè што учесниците треба да подготват",
     "Status" : "Статус",
     "Confirmed" : "Потврдено",
     "Canceled" : "Откажано",
@@ -494,11 +603,18 @@ OC.L10N.register(
     "Error while sharing file" : "Грешка при споделување на датотека",
     "Error while sharing file with user" : "Грешка при споделување на датотека со корисник",
     "Attachment {fileName} already exists!" : "Прилогот {fileName} веќе постои!",
+    "Attachment {fileName} added!" : "Прилогот {fileName} е додаден!",
+    "An error occurred during uploading file {fileName}" : "Настана грешка при прикачување на датотека {fileName}",
     "An error occurred during getting file information" : "Настана грешка при преземање на информации од датотека",
     "An error occurred, unable to delete the calendar." : "Настана грешка, неможе да се избрише календарот.",
     "Imported {filename}" : "Импортирано {filename}",
     "This is an event reminder." : "Ова е потсетник за настан.",
     "Appointment not found" : "Терминот не е пронајден",
-    "User not found" : "Корисникот не е пронајден"
+    "User not found" : "Корисникот не е пронајден",
+    "Shortcut overview" : "Преглед на кратенки преку тастатура",
+    "Enable simplified editor" : "Овозможи поедноставен уредувач",
+    "Limit the number of events displayed in the monthly view" : "Ограничи број на настани прикажани во месечниот преглед",
+    "Time increments" : "Временско зголемување",
+    "Show keyboard shortcuts" : "Прикажи кратенки преку тастатура"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
