@@ -168,6 +168,7 @@ OC.L10N.register(
     "Automatic" : "Automatisk",
     "Automatic ({detected})" : "Automatisk ({detected})",
     "New setting was not saved successfully." : "Ny innstilling ble ikke lagret.",
+    "Timezone" : "Tidssone",
     "Navigation" : "Navigasjon",
     "Previous period" : "Forrige periode",
     "Next period" : "Neste periode",
@@ -185,7 +186,6 @@ OC.L10N.register(
     "Save edited event" : "Lagre endret hendelse",
     "Delete edited event" : "Slett endret hendelse",
     "Duplicate event" : "Dupliser hendelse",
-    "Shortcut overview" : "Oversikt over snarveier",
     "or" : "eller",
     "Calendar settings" : "Kalenderinnstillinger",
     "At event start" : "Ved hendelsens start",
@@ -193,19 +193,18 @@ OC.L10N.register(
     "Failed to save default calendar" : "Lagring av standard kalender feilet",
     "CalDAV link copied to clipboard." : "CalDAV-lenke kopiert til utklippstavlen.",
     "CalDAV link could not be copied to clipboard." : "CalDAV-lenke kunne ikke bli kopiert til utklippstavlen.",
-    "Enable birthday calendar" : "Aktiver fødselsdagkalender",
-    "Show tasks in calendar" : "Vis oppgaver i kalender",
-    "Enable simplified editor" : "Aktiver forenklet redigering",
-    "Limit the number of events displayed in the monthly view" : "Begrens antall hendelser som vises i månedsvisningen",
-    "Show weekends" : "Vis helger",
-    "Show week numbers" : "Vis ukenummer",
-    "Time increments" : "Tidsøkninger",
-    "Default calendar for incoming invitations" : "Standard kalender for innkommende invitasjoner",
-    "Default reminder" : "Standardpåminnelse",
+    "General" : "Generell",
+    "Personal availability settings" : "Personlig ledighets-innstillinger",
     "Copy primary CalDAV address" : "Kopier primær CalDAV-adresse",
     "Copy iOS/macOS CalDAV address" : "Kopier CalDAV-lenke for iOS/macOS",
-    "Personal availability settings" : "Personlig ledighets-innstillinger",
-    "Show keyboard shortcuts" : "Vis tastatursnarveier",
+    "Enable birthday calendar" : "Aktiver fødselsdagkalender",
+    "Show tasks in calendar" : "Vis oppgaver i kalender",
+    "Show weekends" : "Vis helger",
+    "Show week numbers" : "Vis ukenummer",
+    "Editing" : "Rediger",
+    "Default calendar for incoming invitations" : "Standard kalender for innkommende invitasjoner",
+    "Default reminder" : "Standardpåminnelse",
+    "Keyboard shortcuts" : "Tastatursnarveier",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minutt","{duration} minutter"],
     "0 minutes" : "0 minutter",
     "_{duration} hour_::_{duration} hours_" : ["{duration} time","{duration} timer"],
@@ -395,6 +394,8 @@ OC.L10N.register(
     "Update this occurrence" : "Oppdater denne hendelsen",
     "Public calendar does not exist" : "Offentlig kalender finnes ikke",
     "Maybe the share was deleted or has expired?" : "Er deling slettet eller utløpt?",
+    "Yes" : "Ja",
+    "No" : "Nei",
     "Maybe" : "Kanskje",
     "Create" : "Opprett",
     "from {formattedDate}" : "fra {formattedDate}",
@@ -454,7 +455,10 @@ OC.L10N.register(
     "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Vedlegg som krever delt tilgang","Vedlegg som krever delt tilgang"],
     "Untitled event" : "Hendelse uten tittel",
     "Close" : "Lukk",
+    "Title" : "Navn",
+    "30 min" : "30 min",
     "Participants" : "Deltakere",
+    "Submit" : "Send inn",
     "Subscribe to {name}" : "Abonner på {name}",
     "Export {name}" : "Eksporter {name}",
     "Anniversary" : "Jubileum",
@@ -547,6 +551,11 @@ OC.L10N.register(
     "This is an event reminder." : "Dette er en hendelsespåminnelse.",
     "Error while parsing a PROPFIND error" : "Feil under analyse av en PROPFIND-feil",
     "Appointment not found" : "Avtale ikke funnet",
-    "User not found" : "Fant ikke brukeren"
+    "User not found" : "Fant ikke brukeren",
+    "Shortcut overview" : "Oversikt over snarveier",
+    "Enable simplified editor" : "Aktiver forenklet redigering",
+    "Limit the number of events displayed in the monthly view" : "Begrens antall hendelser som vises i månedsvisningen",
+    "Time increments" : "Tidsøkninger",
+    "Show keyboard shortcuts" : "Vis tastatursnarveier"
 },
 "nplurals=2; plural=(n != 1);");
