@@ -41,6 +41,8 @@ OC.L10N.register(
     "Comment:" : "Opmerking:",
     "You have a new appointment booking \"%s\" from %s" : "Je hebt een nieuwe afspraakboeking \"%s\" van %s",
     "Dear %s, %s (%s) booked an appointment with you." : "Beste %s, %s (%s) heeft een afspraak met je geboekt.",
+    "Location:" : "Locatie:",
+    "Duration:" : "Duur:",
     "A Calendar app for Nextcloud" : "Een agenda-app voor Nextcloud",
     "Previous day" : "Vorige dag",
     "Previous week" : "Vorige week",
@@ -147,6 +149,8 @@ OC.L10N.register(
     "Share calendar" : "Delen kalender",
     "Unshare from me" : "Stop delen met mij",
     "Save" : "Opslaan",
+    "No title" : "Geen titel",
+    "View" : "Bekijken",
     "Import calendars" : "Importeer agenda's",
     "Please select a calendar to import into …" : "Selecteer een agenda om naar te importeren  ...",
     "Filename" : "Bestandsnaam",
@@ -166,6 +170,7 @@ OC.L10N.register(
     "Automatic" : "Automatisch",
     "Automatic ({detected})" : "Automatisch ({detected})",
     "New setting was not saved successfully." : "De nieuwe instelling is niet goed opgeslagen.",
+    "Timezone" : "Tijdzone",
     "Navigation" : "Navigatie",
     "Previous period" : "Vorige periode",
     "Next period" : "Volgende periode",
@@ -183,7 +188,6 @@ OC.L10N.register(
     "Save edited event" : "Aangepaste afspraak opslaan",
     "Delete edited event" : "Aangepaste afspraak verwijderen",
     "Duplicate event" : "Duplicaat afspraak",
-    "Shortcut overview" : "Snelkoppeling overzicht",
     "or" : "of",
     "Calendar settings" : "Agenda instellingen",
     "At event start" : "Bij start gebeurtenis",
@@ -191,19 +195,18 @@ OC.L10N.register(
     "Failed to save default calendar" : "Kon standaardagenda niet opslaan",
     "CalDAV link copied to clipboard." : "CalDAV link gekopiëerd naar klembord.",
     "CalDAV link could not be copied to clipboard." : "CalDAV link kon niet worden gekopieerd naar klembord.",
-    "Enable birthday calendar" : "Verjaardagskalender inschakelen",
-    "Show tasks in calendar" : "Toon taken in agenda",
-    "Enable simplified editor" : "Eenvoudige editor inschakelen",
-    "Limit the number of events displayed in the monthly view" : "Beperk het aantal evenementen dat wordt weergegeven in de maandweergave",
-    "Show weekends" : "Toon weekenden",
-    "Show week numbers" : "Tonen weeknummers",
-    "Time increments" : "Time-toename",
-    "Default calendar for incoming invitations" : "Standaardagenda voor inkomende uitnodigingen",
-    "Default reminder" : "Standaard herinnering",
+    "General" : "Algemeen",
+    "Personal availability settings" : "Persoonlijke beschikbaarheidsinstellingen",
     "Copy primary CalDAV address" : "Kopieer primair CalDAV adres",
     "Copy iOS/macOS CalDAV address" : "Kopieer iOS/macOS CalDAV adres",
-    "Personal availability settings" : "Persoonlijke beschikbaarheidsinstellingen",
-    "Show keyboard shortcuts" : "Toon sneltoetsen",
+    "Enable birthday calendar" : "Verjaardagskalender inschakelen",
+    "Show tasks in calendar" : "Toon taken in agenda",
+    "Show weekends" : "Toon weekenden",
+    "Show week numbers" : "Tonen weeknummers",
+    "Editing" : "Bewerken",
+    "Default calendar for incoming invitations" : "Standaardagenda voor inkomende uitnodigingen",
+    "Default reminder" : "Standaard herinnering",
+    "Keyboard shortcuts" : "Toetsenbord sneltoetsen",
     "Appointment schedule successfully created" : "Afspraakschema succesvol aangemaakt",
     "Appointment schedule successfully updated" : "Afspraakschema succesvol aangepast",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minuut","{duration} minuten"],
@@ -258,7 +261,6 @@ OC.L10N.register(
     "Could not book the appointment. Please try again later or contact the organizer." : "Kon afspraak niet boeken. Probeer later opnieuw of neem contact op met de organisator.",
     "Back" : "Terug",
     "Book appointment" : "Boek afspraak",
-    "Create a new conversation" : "Maak een nieuw gesprek",
     "Select conversation" : "Selecteer een gesprek",
     "on" : "op",
     "at" : "om",
@@ -400,6 +402,9 @@ OC.L10N.register(
     "Update this occurrence" : "Deze afspraak bijwerken",
     "Public calendar does not exist" : "Publieke agenda bestaat niet",
     "Maybe the share was deleted or has expired?" : "Mogelijk is het gedeelde item verwijderd of verlopen?",
+    "Yes" : "Ja",
+    "No" : "Nee",
+    "Create" : "Creëer",
     "from {formattedDate}" : "van {formattedDate}",
     "to {formattedDate}" : "tot {formattedDate}",
     "on {formattedDate}" : "op {formattedDate}",
@@ -423,7 +428,6 @@ OC.L10N.register(
     "No valid public calendars configured" : "Geen juiste openbare agenda's ingesteld",
     "Speak to the server administrator to resolve this issue." : "Vraag je beheerder om dit probleem op te lossen.",
     "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Openbare feestdagenkalenders worden verstrekt door Thunderbird. Kalendergegevens worden gedownload van {website}.",
-    "These public calendars are suggested by the sever administrator. Calendar data will be downloaded from the respective website." : "Deze openbare agenda's zijn voorgesteld door de beheerder van de server. Agandagegevens worden gedownload van de respectievelijke website.",
     "By {authors}" : "Door {authors}",
     "Subscribed" : "Geabonneerd",
     "Subscribe" : "Abonneren",
@@ -458,6 +462,11 @@ OC.L10N.register(
     "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Bijlagen die gedeelde toegang vereisen","Bijlagen die gedeelde toegang vereisen"],
     "Untitled event" : "Afspraken zonder naam",
     "Close" : "Sluiten",
+    "Selected" : "Geselecteerd",
+    "Title" : "Titel",
+    "30 min" : "30 min",
+    "Participants" : "Deelnemers",
+    "Submit" : "Indienen",
     "Subscribe to {name}" : "Abonneren op {name}",
     "Export {name}" : "Exporteer {name}",
     "Anniversary" : "Verjaardag",
@@ -549,12 +558,10 @@ OC.L10N.register(
     "This is an event reminder." : "Dit is een herinnering aan een evenement.",
     "Appointment not found" : "Afspraak niet gevonden",
     "User not found" : "Gebruiker niet gevonden",
-    "Reminder" : "Herinnering",
-    "+ Add reminder" : "+ Toevoegen herinnering",
-    "Select automatic slot" : "Selecteer automatisch tijdsblok",
-    "with" : "met",
-    "Available times:" : "Beschikbare tijden:",
-    "Suggestions" : "Suggesties",
-    "Details" : "Details"
+    "Shortcut overview" : "Snelkoppeling overzicht",
+    "Enable simplified editor" : "Eenvoudige editor inschakelen",
+    "Limit the number of events displayed in the monthly view" : "Beperk het aantal evenementen dat wordt weergegeven in de maandweergave",
+    "Time increments" : "Time-toename",
+    "Show keyboard shortcuts" : "Toon sneltoetsen"
 },
 "nplurals=2; plural=(n != 1);");
