@@ -149,23 +149,22 @@ OC.L10N.register(
     "Save edited event" : "Gravar evento editado",
     "Delete edited event" : "Apagar evento editado",
     "Duplicate event" : "Duplicar evento",
-    "Shortcut overview" : "Visão geral de atalhos",
     "or" : "ou",
     "Calendar settings" : "Configurações do calendário",
     "No reminder" : "Nenhum lembrete",
     "CalDAV link copied to clipboard." : "Ligação CalDAV copiada para a área de transferência.",
     "CalDAV link could not be copied to clipboard." : "Não foi possível copiar a ligação CalDAV para a área de transferência.",
-    "Enable birthday calendar" : "Ativar calendário de aniversários",
-    "Show tasks in calendar" : "Mostrar tarefas no calendário",
-    "Enable simplified editor" : "Ativar editor simplificado",
-    "Show weekends" : "Mostrar fins-de-semana",
-    "Show week numbers" : "Mostrar o número das semanas",
-    "Time increments" : "Incrementos de tempo",
-    "Default reminder" : "Lembrete padrão",
+    "General" : "Geral",
+    "Personal availability settings" : "Configurações de disponibilidade pessoal",
     "Copy primary CalDAV address" : "Copiar endereço CalDAV primário",
     "Copy iOS/macOS CalDAV address" : "Copiar endereço iOS/macOS CalDAV",
-    "Personal availability settings" : "Configurações de disponibilidade pessoal",
-    "Show keyboard shortcuts" : "Mostrar atalhos de teclado",
+    "Enable birthday calendar" : "Ativar calendário de aniversários",
+    "Show tasks in calendar" : "Mostrar tarefas no calendário",
+    "Show weekends" : "Mostrar fins-de-semana",
+    "Show week numbers" : "Mostrar o número das semanas",
+    "Editing" : "A editar",
+    "Default reminder" : "Lembrete padrão",
+    "Keyboard shortcuts" : "Atalhos de teclado",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minuto","{duration} minutos","{duration} minutos"],
     "0 minutes" : "0 minutos",
     "_{duration} hour_::_{duration} hours_" : ["{duration} hora","{duration} horas","{duration} horas"],
@@ -267,6 +266,8 @@ OC.L10N.register(
     "weekend day" : "dia do fim-de-semana",
     "Resources" : "Recursos",
     "available" : "disponível",
+    "Yes" : "Sim",
+    "No" : "Não",
     "Create" : "Criar",
     "Pick a date" : "Escolha uma data",
     "Global" : "Global",
@@ -281,6 +282,7 @@ OC.L10N.register(
     "Selected" : "Selecionado",
     "Title" : "Título",
     "Participants" : "Participantes",
+    "Submit" : "Submeter",
     "Anniversary" : "Aniversário",
     "Miscellaneous" : "Diversos",
     "Week {number} of {year}" : "Semana {number} do {year}",
@@ -303,6 +305,10 @@ OC.L10N.register(
     "Categories" : "Categorias",
     "Error while sharing file" : "Erro ao partilhar ficheiro",
     "An error occurred, unable to delete the calendar." : "Ocorreu um erro que impede que o calendário seja apagado",
-    "User not found" : "Utilizador não encontrado"
+    "User not found" : "Utilizador não encontrado",
+    "Shortcut overview" : "Visão geral de atalhos",
+    "Enable simplified editor" : "Ativar editor simplificado",
+    "Time increments" : "Incrementos de tempo",
+    "Show keyboard shortcuts" : "Mostrar atalhos de teclado"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
