@@ -1,6 +1,7 @@
 OC.L10N.register(
     "calendar",
     {
+    "Provided email-address is too long" : "Emailul furnizat este prea lung",
     "User-Session unexpectedly expired" : "Sesiunea-Utilizatorului a expirat în mod neașteptat",
     "Provided email-address is not valid" : "Adresa de email furnizată este invalidă",
     "%s has published the calendar »%s«" : "%sa publicat calendarul »%s«",
@@ -11,114 +12,152 @@ OC.L10N.register(
     "Open »%s«" : "Accesează »%s«",
     "Cheers!" : "Noroc!",
     "Upcoming events" : "Evenimente viitoare",
+    "No more events today" : "Nu mai sunt evenimente astăzi",
+    "No upcoming events" : "Niciun eveniment următor",
+    "More events" : "Mai multe evenimente",
+    "%1$s with %2$s" : "%1$s cu %2$s",
+    "Calendar" : "Calendar",
+    "New booking {booking}" : "Rezervare nouă {booking}",
+    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) a programat întâlnirea \"{config_display_name}\" pe {date_time}.",
     "Appointments" : "Întâlniri",
     "Schedule appointment \"%s\"" : "Planifică programarea \"%s\"",
     "Schedule an appointment" : "Planifică o programare",
     "Prepare for %s" : "Pregăteste-te de %s",
     "Follow up for %s" : "Urmărește-ne pentru %s",
+    "Your appointment \"%s\" with %s needs confirmation" : "Întâlnirea \"%s\" cu %s necesită confirmare",
     "Dear %s, please confirm your booking" : "Dragă %s, te rog să confirmi rezervarea ta",
     "Confirm" : "Confirmă",
+    "Description:" : "Descriere:",
     "This confirmation link expires in %s hours." : "Acest link de confirmare expira în %s ore. ",
+    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Dacă totuși doriți să anulați întâlnirea, contactați organizatorul răspunzându-i la acest mail sau vizitând pagina de profil a acestuia.",
+    "Your appointment \"%s\" with %s has been accepted" : "Întâlnirea \"%s\" cu %s a fost acceptată",
+    "Dear %s, your booking has been accepted." : "Dragă %s, rezervarea a fost acceptată.",
+    "Appointment for:" : "Programare pentru:",
     "Date:" : "Data:",
+    "You will receive a link with the confirmation email" : "Veți primi un link cu emailul de confirmare",
     "Where:" : "Unde:",
-    "Calendar" : "Calendar",
+    "Comment:" : "Comentariu:",
+    "You have a new appointment booking \"%s\" from %s" : "Aveți o nouă rezervare \"%s\" de la %s",
+    "Dear %s, %s (%s) booked an appointment with you." : "Dragă %s, %s (%s) a rezervat o întâlnire cu tine.",
+    "Location:" : "Locaţie:",
     "A Calendar app for Nextcloud" : "O aplicație de tip calendar pentru Nextcloud",
     "Previous day" : "Ziua anterioară",
     "Previous week" : "Săptămâna anterioară",
+    "Previous year" : "Anul anterior",
     "Previous month" : "Luna anterioară",
     "Next day" : "Ziua următoare",
     "Next week" : "Saptămâna următoare",
+    "Next year" : "Aanul viitor",
     "Next month" : "Luna următoare",
-    "New event" : "Eveniment nou",
+    "Create new event" : "Creează un nou eveniment",
+    "Event" : "Eveniment",
     "Today" : "Astăzi",
     "Day" : "Zi",
     "Week" : "Săptămâna",
     "Month" : "Luna",
+    "Year" : "An",
     "List" : "Listă",
+    "Appointment link was copied to clipboard" : "Linkul programării a fost copiat în clipboard",
+    "Appointment link could not be copied to clipboard" : "Linkul programării nu a putut fi copiat în clipboard",
     "Preview" : "Previzualizare",
     "Copy link" : "Copiază link",
     "Edit" : "Editează",
     "Delete" : "Șterge",
-    "Appointment link was copied to clipboard" : "Linkul programării a fost copiat în clipboard",
-    "Appointment link could not be copied to clipboard" : "Linkul programării nu a putut fi copiat în clipboard",
-    "Add new" : "Adaugă nou",
-    "Untitled calendar" : "Calendar nedenumit",
-    "Edit name" : "Modifică numele",
-    "Saving name …" : "Se salvează numele ...",
-    "Edit color" : "Modifică culoarea",
-    "Saving color …" : "Se salvează culoarea  ...",
-    "Copy private link" : "Copiază link privat",
-    "Export" : "Exportă",
-    "Unshare from me" : "Anulare partajarea cu mine",
+    "Create new" : "Crează nou",
+    "Disable calendar \"{calendar}\"" : "Dezactivează calendarul \"{calendar}\"",
+    "Disable untitled calendar" : "Dezactivează calendarul fără nume",
+    "Enable calendar \"{calendar}\"" : "Activează calendarul \"{calendar}\"",
+    "Enable untitled calendar" : "Activează calendarul fără nume",
     "An error occurred, unable to change visibility of the calendar." : "A apărut o eroare, nu se poate schimba vizibilitatea calendarului.",
-    "An error occurred, unable to delete the calendar." : "A apărut o eroare, nu se poate șterge calendarul.",
-    "Calendar link copied to clipboard." : "Linkul către calendar a fost copiat în clipboard.",
-    "Calendar link could not be copied to clipboard." : "Linkul către calendar nu a putut fi copiat în clipboard.",
-    "An error occurred, unable to rename the calendar." : "A apărut o eroare, acest calendar nu se poate redenumi.",
-    "An error occurred, unable to change the calendar's color." : "A apărut o eroare, nu se poate schimba culoarea calendarului.",
+    "Untitled calendar" : "Calendar nedenumit",
+    "Shared with you by" : "Partajat cu tine de",
+    "Edit and share calendar" : "Editează și partajează calendarul",
+    "Edit calendar" : "Editare calendar",
     "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Oprirea partajării calendarului in {countdown} secundă","Oprirea partajării calendarului în {countdown} secunde","Oprirea partajării calendarului în {countdown} de secunde"],
     "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Se șterge calendarul în {countdown} secundă","Se șterge calendarul în {countdown} secunde","Se șterge calendarul în {countdown} de secunde"],
-    "Share link" : "Partajază legătură",
-    "Publish calendar" : "Publică calendarul",
-    "Publishing calendar" : "Se publică calendarul",
-    "Copy public link" : "Copiză link-ul public",
-    "Send link to calendar via email" : "Trimite link-ul către calendar folosind email",
-    "Enter one address" : "Introdu o adresă",
-    "Sending email …" : "Email-ul se trimite ...",
-    "Copy subscription link" : "Copiază linkul abonamentului",
-    "Copying link …" : "Copiază link ...",
-    "Copied link" : "Link copiat",
-    "Could not copy link" : "Nu s-a putut copia link-ul",
-    "Copy embedding code" : "Copiați codul de încorporare",
-    "Copying code …" : "Se copiază codul ...",
-    "Copied code" : "Codul a fost copiat",
-    "Could not copy code" : "Nu sa putut copia codul",
-    "Delete share link" : "Șterge linkul partajat",
-    "Deleting share link …" : "Se şterge linkul de partajare ...",
-    "An error occurred, unable to publish calendar." : "A apărut o eroare, nu se poate publica calendarul.",
-    "An error occurred, unable to send email." : "A apărut o eroare, nu se poate trimite email-ul.",
-    "Embed code copied to clipboard." : "Codul a fost copiat în clipboard.",
-    "Embed code could not be copied to clipboard." : "Codul nu a putut fi copiat in clipboard.",
-    "Unpublishing calendar failed" : "Retragerea calendarului a eşuat",
-    "Share with users or groups" : "Partajează cu utilizatori sau grupuri",
-    "No users or groups" : "Nu sunt utilizatori sau grupuri",
-    "can edit" : "poate edita",
-    "Unshare with {displayName}" : "Retrage cu {displayName}",
-    "An error occurred, unable to change the unshare the calendar." : "A apărut o eroare, nu se poate schimba retragerea calendarului.",
-    "An error occurred, unable to change the permission of the share." : "A apărut o eroare, nu se poate schimba permisiunile fişierelor partajate.",
+    "An error occurred, unable to create the calendar." : "A apărut o eroare, nu se poate creea acest calendar.",
+    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Vă rugăm să introduceți un link valid (ce începe cu ttp://, https://, webcal://, sau webcals://)",
+    "Calendars" : "Calendare",
+    "Add new" : "Adaugă nou",
     "New calendar" : "Calendar nou",
     "Name for new calendar" : "Numele noului calendar",
     "Creating calendar …" : "Se creează un calendar nou ...",
     "New calendar with task list" : "Calendar nou cu listă",
     "New subscription from link (read-only)" : "Abonament nou folosind un link (doar citirea calendarului)",
     "Creating subscription …" : "Se creează abonamentul ...",
-    "An error occurred, unable to create the calendar." : "A apărut o eroare, nu se poate creea acest calendar.",
-    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Vă rugăm să introduceți un link valid (ce începe cu ttp://, https://, webcal://, sau webcals://)",
-    "Trash bin" : "Coș de gunoi",
-    "Name" : "Nume",
-    "Deleted" : "Șters",
-    "Restore" : "Restaurare",
-    "Delete permanently" : "Șterge permanent",
-    "Empty trash bin" : "Golește coșul de gunoi",
+    "Add public holiday calendar" : "Adaugă calendar de sărbători",
+    "Calendar link copied to clipboard." : "Linkul către calendar a fost copiat în clipboard.",
+    "Calendar link could not be copied to clipboard." : "Linkul către calendar nu a putut fi copiat în clipboard.",
+    "Copy subscription link" : "Copiază linkul abonamentului",
+    "Copying link …" : "Copiază link ...",
+    "Copied link" : "Link copiat",
+    "Could not copy link" : "Nu s-a putut copia link-ul",
+    "Export" : "Exportă",
+    "Untitled item" : "Element fără nume",
     "Unknown calendar" : "Calendar necunoscut",
     "Could not load deleted calendars and objects" : "Nu s-au putut încărca obiectele și calendarele",
     "Could not restore calendar or event" : "Nu s-a putut restaura calendarul sau evenimentul",
     "Do you really want to empty the trash bin?" : "Doriti sigur sa goliți conținutul coșului de gunoi ?",
+    "Empty trash bin" : "Golește coșul de gunoi",
+    "Trash bin" : "Coș de gunoi",
+    "Loading deleted items." : "Se încarcă elementele șterse.",
+    "You do not have any deleted items." : "Nu aveți elemente șterse.",
+    "Name" : "Nume",
+    "Deleted" : "Șters",
+    "Restore" : "Restaurare",
+    "Delete permanently" : "Șterge permanent",
+    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Coșul de gunoi este golit în {numDays} zi","Coșul de gunoi este golit în {numDays} zile","Coșul de gunoi este golit în {numDays} zile"],
     "Could not update calendar order." : "Nu s-a putut actualiza ordinea calendarului.",
+    "Hidden" : "Ascuns",
+    "Internal link" : "Link intern",
+    "A private link that can be used with external clients" : "Link privat ce poate fi folosit cu clienți externi",
+    "Copy internal link" : "Copiază linkul intern",
+    "An error occurred, unable to publish calendar." : "A apărut o eroare, nu se poate publica calendarul.",
+    "An error occurred, unable to send email." : "A apărut o eroare, nu se poate trimite email-ul.",
+    "Embed code copied to clipboard." : "Codul a fost copiat în clipboard.",
+    "Embed code could not be copied to clipboard." : "Codul nu a putut fi copiat in clipboard.",
+    "Unpublishing calendar failed" : "Retragerea calendarului a eşuat",
+    "Share link" : "Partajază legătură",
+    "Copy public link" : "Copiză link-ul public",
+    "Send link to calendar via email" : "Trimite link-ul către calendar folosind email",
+    "Enter one address" : "Introdu o adresă",
+    "Sending email …" : "Email-ul se trimite ...",
+    "Copy embedding code" : "Copiați codul de încorporare",
+    "Copying code …" : "Se copiază codul ...",
+    "Copied code" : "Codul a fost copiat",
+    "Could not copy code" : "Nu sa putut copia codul",
+    "Delete share link" : "Șterge linkul partajat",
+    "Deleting share link …" : "Se şterge linkul de partajare ...",
+    "An error occurred while unsharing the calendar." : "Eroare la eliminarea partajării calendarului.",
+    "An error occurred, unable to change the permission of the share." : "A apărut o eroare, nu se poate schimba permisiunile fişierelor partajate.",
+    "can edit" : "poate edita",
+    "Unshare with {displayName}" : "Retrage cu {displayName}",
+    "Share with users or groups" : "Partajează cu utilizatori sau grupuri",
+    "No users or groups" : "Nu sunt utilizatori sau grupuri",
+    "Failed to save calendar name and color" : "Eroare la salvarea numelui calendarului și a culorii",
+    "Calendar name …" : "Numele calendarului ...",
+    "Share calendar" : "Partajează calendarul",
+    "Unshare from me" : "Anulare partajarea cu mine",
+    "Save" : "Salvează",
+    "View" : "Vizualizare",
     "Import calendars" : "Importă calendare",
     "Please select a calendar to import into …" : "Vă rugăm să selectaţi un calendar în care să importaţi ...",
     "Filename" : "Nume fișier",
     "Calendar to import into" : "Calendarul în care se importă",
     "Cancel" : "Anulează",
     "_Import calendar_::_Import calendars_" : ["Importă calendar","Importă calendare","Importă calendare"],
+    "Select the default location for attachments" : "Selectează locația implicită pentru atașamente",
+    "Invalid location selected" : "Locație invalidă",
+    "Attachments folder successfully saved." : "Folderul de atașamente a fost salvat.",
+    "Error on saving attachments folder." : "Eroare la salvarea folderului de atașamente.",
+    "Default attachments location" : "Locația implicită a atașamentelor",
     "{filename} could not be parsed" : "{filename} nu a putut fi analizat",
     "No valid files found, aborting import" : "Nu au fost găsite fişiere valide, importarea se opreşte",
+    "_Successfully imported %n event_::_Successfully imported %n events_" : ["A fost importat %n eveniment","Au fost importate %n evenimente","Au fost importate %n evenimente"],
     "Import partially failed. Imported {accepted} out of {total}." : "Importarea a eşuat parţial. S-au importat  {accepted} din {total}.",
     "Automatic" : "Automat",
     "Automatic ({detected})" : "Automat ({detectat})",
     "New setting was not saved successfully." : "Noile setări nu au fost salvate cu succes.",
-    "Shortcut overview" : "Prezentare generală a comenzilor rapide",
-    "or" : "sau",
     "Navigation" : "Navigare",
     "Previous period" : "Perioada anterioară",
     "Next period" : "Perioada următoare",
@@ -126,27 +165,31 @@ OC.L10N.register(
     "Day view" : "Vizualizare pe zi",
     "Week view" : "Vizualizare pe săptămână",
     "Month view" : "Vizualizare pe lună",
+    "Year view" : "Vizualizare an",
     "List view" : "Vizualizare sub formă de listă",
     "Actions" : "Acțiuni",
     "Create event" : "Creează eveniment",
     "Show shortcuts" : "Arată scurtături",
-    "Enable birthday calendar" : "Activează calendarul cu zile de naştere",
-    "Show tasks in calendar" : "Arată sarcinile în calendar",
-    "Enable simplified editor" : "Activează editorul simplificat",
-    "Limit visible events per view" : "Limitează evenimentele vizibile în fiecare mod de vizualizare",
-    "Show weekends" : "Arată weekend-uri",
-    "Show week numbers" : "Afișați numerele săptămânilor",
-    "Time increments" : "Incremente de timp",
-    "Default reminder" : "Memento implicit",
-    "Copy primary CalDAV address" : "Copiază adresa primară CalDAV",
-    "Copy iOS/macOS CalDAV address" : "Copiază adresa iOS/OS X CalDAV",
-    "Personal availability settings" : "Setări de disponibilitate",
-    "Show keyboard shortcuts" : "Arată scurtături",
+    "Close editor" : "Închide editorul",
+    "Save edited event" : "Salvează evenimentul editat",
+    "Delete edited event" : "Șterge evenimentul editat",
+    "Duplicate event" : "Duplicare eveniment",
+    "or" : "sau",
+    "Calendar settings" : "Setări calendar",
     "No reminder" : "Fără mementouri",
     "CalDAV link copied to clipboard." : "Link-ul CAlDAV a fost copiat în clipboard.",
     "CalDAV link could not be copied to clipboard." : "Linkul CalDAV nu a putut fi copiat în clipboard.",
-    "Appointment was created successfully" : "Programarea a fost creeata cu succes",
-    "Appointment was updated successfully" : "Programarea a fost actualizată cu succes",
+    "General" : "General",
+    "Personal availability settings" : "Setări de disponibilitate",
+    "Copy primary CalDAV address" : "Copiază adresa primară CalDAV",
+    "Copy iOS/macOS CalDAV address" : "Copiază adresa iOS/OS X CalDAV",
+    "Enable birthday calendar" : "Activează calendarul cu zile de naştere",
+    "Show tasks in calendar" : "Arată sarcinile în calendar",
+    "Show weekends" : "Arată weekend-uri",
+    "Show week numbers" : "Afișați numerele săptămânilor",
+    "Editing" : "Se modifică",
+    "Default reminder" : "Memento implicit",
+    "Keyboard shortcuts" : "Scurtături din tastatură",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minut","{duration} minute","{duration} de minute"],
     "0 minutes" : "0 minute",
     "_{duration} hour_::_{duration} hours_" : ["{duration} oră","{duration} ore","{duration} de ore"],
@@ -157,7 +200,11 @@ OC.L10N.register(
     "To configure appointments, add your email address in personal settings." : "Pentru a configura programările, adăugați-vă adresa email în setările personale.",
     "Public – shown on the profile page" : "Public- arată pepagina de profil",
     "Private – only accessible via secret link" : "Private - accesibil doar prin folosirea unui link secret",
+    "Update" : "Actualizare",
+    "Appointment name" : "Numele programării",
     "Location" : "Locație",
+    "Create a Talk room" : "Creează o cameră Talk",
+    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "Va fi generat un link unic  pentru toate programările rezervate și vor fi trimise în mailul de confirmare",
     "Description" : "Descriere",
     "Visibility" : "Vizibil",
     "Duration" : "Durată",
@@ -182,17 +229,16 @@ OC.L10N.register(
     "Minimum time before next available slot" : "Timpul minim înaintea următorului slot de timp disponibil",
     "Max slots per day" : "Numărul de sloturi pe zi",
     "Limit how far in the future appointments can be booked" : "Limitează cât timp în viitor programările pot fi create",
-    "Create appointment" : "Creează programare",
-    "Edit appointment" : "Editează programarea",
-    "Save" : "Salvează",
-    "Update" : "Actualizare",
+    "Please confirm your reservation" : "Confirmați, vă rog, rezervarea",
     "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Ți-am trimis un email cu detalii. Te rugăm să confirmi programarea ta folosind linkul din email. Poți închide această pagină acum.",
     "Your name" : "Numele tău",
     "Your email address" : "Adresa ta de email",
     "Please share anything that will help prepare for our meeting" : "Te rugăm să împărtășești orice informație ce ne poate ajuta în pregătirea pentru ședința noastră.",
     "Could not book the appointment. Please try again later or contact the organizer." : "Nu s-a putut creea evenimentul. Vă rugăm să încercați mai târziu sau să contactați organizatorul.",
-    "Book the appointment" : "Creează programarea",
-    "Reminder" : "Memento",
+    "Back" : "Înapoi",
+    "Select conversation" : "Selectare conversație",
+    "on" : "pe",
+    "at" : "la",
     "before at" : "Înainte de la",
     "Notification" : "Notificări",
     "Email" : "Email",
@@ -203,92 +249,180 @@ OC.L10N.register(
     "Edit time" : "Editează ora",
     "Save time" : "Salvează ora",
     "Remove reminder" : "Elimină memento",
-    "on" : "pe",
-    "at" : "la",
-    "+ Add reminder" : "+ Adaugă memento",
     "Add reminder" : "Adaugă memento",
-    "_second_::_seconds_" : ["secundă","secunde","secunde"],
-    "_minute_::_minutes_" : ["minut","minute","minute"],
-    "_hour_::_hours_" : ["oră","ore","ore"],
-    "_day_::_days_" : ["zi","zile","zile"],
-    "_week_::_weeks_" : ["săptămână","săptămâni","săptămâni"],
+    "seconds" : "secunde",
+    "minutes" : "minute",
+    "hours" : "ore",
+    "days" : "zile",
+    "weeks" : "săptămâni",
+    "Choose a file to add as attachment" : "Selectați un fișier ca atașament",
+    "Choose a file to share as a link" : "Selectați un fișier pentru partajare ca link",
+    "Attachment {name} already exist!" : "Atașamentul {name} există!",
+    "No attachments" : "Fără atașamente",
+    "Add from Files" : "Adaugă din Fișiere",
+    "Upload from device" : "Încarcă din dispozitiv",
+    "Delete file" : "Șterge fișier",
+    "_{count} attachment_::_{count} attachments_" : ["{count} atașament","{count} atașamente","{count} atașamente"],
+    "Suggested" : "Sugerat",
     "Available" : "Disponibil",
+    "Invitation accepted" : "Invitația a fost acceptată",
+    "Accepted {organizerName}'s invitation" : "A fost acceptată invitația {organizerName}",
+    "Participation marked as tentative" : "A fost marcată intenția de participare",
+    "Invitation is delegated" : "Invitația este delegată",
     "Not available" : "Nu este disponibil",
-    "Availability of attendees, resources and rooms" : "Disponibilitatea participanților, resurse și camere",
+    "Invitation declined" : "Invitația a fost respinsă",
+    "Declined {organizerName}'s invitation" : "Invitația {organizerName} respinsă",
+    "Checking availability" : "Se verifică disponibilitatea",
+    "Has not responded to {organizerName}'s invitation yet" : "Nu s-a răspuns încă invitației {organizerName}",
     "{organizer} (organizer)" : "{organizer} (organizer)",
+    "Availability of attendees, resources and rooms" : "Disponibilitatea participanților, resurse și camere",
+    "Out of office" : "În afara serviciului",
+    "Done" : "Realizat",
+    "Free" : "Liber",
     "Busy (tentative)" : "Ocupat (tetentativ)",
     "Busy" : "Ocupat",
-    "Out of office" : "În afara serviciului",
     "Unknown" : "Necunoscut",
-    "Accept" : "Accept",
-    "Decline" : "Refuză",
-    "Tentative" : "Tentativă",
     "The invitation has been accepted successfully." : "Invitația a fost acceptată cu succes.",
     "Failed to accept the invitation." : "Nu s-a acceptat invitația.",
     "The invitation has been declined successfully." : "Invitația a fost refuzată cu succes.",
     "Failed to decline the invitation." : "Invitația nu a putut fi refuzată.",
     "Your participation has been marked as tentative." : "Participarea a fost marcată ca o încercare.",
-    "Create Talk room for this event" : "Creează o cameră Talk pentru acest eveniment",
+    "Failed to set the participation status to tentative." : "Eroare la setarea statusului de intenție de participare.",
+    "Accept" : "Accept",
+    "Decline" : "Refuză",
+    "Tentative" : "Tentativă",
     "No attendees yet" : "Nu exista participați încă",
+    "Successfully appended link to talk room to location." : "S-a adăugat cu succes locației linkul la camera Talk.",
+    "Successfully appended link to talk room to description." : "S-a adăugat cu succes descrierii linkul la camera Talk.",
     "Error creating Talk room" : "Camera Talk nu a putut fi creată",
-    "Send email" : "Trimite email-ul",
+    "Attendees" : "Participanți",
+    "Remove group" : "Înlătură grupul",
+    "Remove attendee" : "Elimină participant",
     "Chairperson" : "Președinte",
     "Required participant" : "Participanți necesari",
     "Optional participant" : "Participanți opționali",
-    "Remove attendee" : "Elimină participant",
+    "_%n member_::_%n members_" : ["%n membru","%n membri","%n membri"],
+    "No match found" : "Nu s-a găsit nimic",
     "(organizer)" : "(organizator)",
+    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Pentru a trimite invitații și răspunsuri, [linkopen]adăugați adresa de mail în setările personale[linkclose].",
     "Remove color" : "Șterge culoarea",
     "Event title" : "Titlul evenimentului",
-    "All day" : "Toată ziua",
-    "from {startDate}" : "începând cu {startDate}",
-    "from {startDate} at {startTime}" : "începând cu {startDate} de la {startTime}",
-    "to {endDate}" : "către {endDate}",
-    "to {endDate} at {endTime}" : "către {endDate} până la {endTime}",
+    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Nu se pot modifica setările zilnice pentru evenimentele care fac parte dintr-un set recurent.",
+    "From" : "De la",
+    "To" : "Către",
     "Repeat" : "Repetă",
-    "End repeat" : "Încheie seria",
-    "Select to end repeat" : "Selectează pentru a încheia seria",
+    "_time_::_times_" : ["dată","ori","ori"],
     "never" : "niciodată",
     "on date" : "la data ",
     "after" : "după",
+    "End repeat" : "Încheie seria",
+    "Select to end repeat" : "Selectează pentru a încheia seria",
+    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Acest eveniment este excepția de recurență a unui set recurent. Nu i se poate adăuga o regulă de recurență.",
     "first" : "primul",
-    "third" : "al treilea",
-    "fourth" : "al patrulea",
-    "fifth" : "al cincilea",
-    "second to last" : "penultimul",
-    "last" : "ultimul",
+    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Modificările regulii de recurență se vor aplica  doar de acum încolo.",
     "Repeat every" : "Se repetă la fiecare",
     "By day of the month" : "după ziua lunii",
     "On the" : "Pe",
+    "_day_::_days_" : ["zi","zile","zile"],
+    "_week_::_weeks_" : ["săptămână","săptămâni","săptămâni"],
     "_month_::_months_" : ["lună","luni","luni"],
     "_year_::_years_" : ["an","ani","ani"],
-    "Suggestions" : "Sugestii",
+    "weekday" : "zi din săptămână",
+    "weekend day" : "ziua din săptămână",
+    "Does not repeat" : "Nu se repetă",
+    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Definiția recurenței acestui eveniment nu este complet suportată de Nextcloud. Dacă editați opțiunile de recurență, s-ar putea pierde unele recurențe.",
+    "No rooms or resources yet" : "Nicio sală sau resursă deocamdată",
+    "Resources" : "Resurse",
+    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} loc","{seatingCapacity} locuri","{seatingCapacity} locuri"],
     "Add resource" : "Adaugă resurse",
     "Has a projector" : "Conține un proiector",
     "Has a whiteboard" : "Conține o tablă de scris",
     "Wheelchair accessible" : "Accesibilă folosind un scaun cu rotile",
     "Remove resource" : "Elimină resurse",
-    "Projector" : "Proiector",
-    "Whiteboard" : "Tablă de scris",
     "Search for resources or rooms" : "Caută resurse sau camere",
     "available" : "disponibil",
     "unavailable" : "nedisponibil",
+    "Projector" : "Proiector",
+    "Whiteboard" : "Tablă de scris",
     "Room type" : "Tipul de cameră",
     "Any" : "Toate",
     "Minimum seating capacity" : "Capacitatea minimă",
-    "More" : "Mai mult",
+    "Update this and all future" : "Actualizează aceasta și toate viitoare",
     "Update this occurrence" : "Actualizați această ședință",
     "Public calendar does not exist" : "Calendarul public nu există",
+    "Maybe the share was deleted or has expired?" : "Poate că partajarea a fost ștearsă sau a expirat?",
+    "Remove participant" : "Elimină participant",
+    "Yes" : "Da",
+    "No" : "Nu",
+    "Create" : "Crează",
+    "from {formattedDate}" : "începând cu {formattedDate}",
+    "to {formattedDate}" : "până la {formattedDate}",
+    "on {formattedDate}" : "pe {formattedDate}",
+    "from {formattedDate} at {formattedTime}" : "începând cu {formattedDate} la {formattedTime}",
+    "to {formattedDate} at {formattedTime}" : "până la data {formattedDate} la {formattedTime}",
+    "on {formattedDate} at {formattedTime}" : "pe {formattedDate} la {formattedTime}",
+    "{formattedDate} at {formattedTime}" : "{formattedDate} la {formattedTime}",
+    "Please enter a valid date" : "Adăugați o dată validă",
+    "Please enter a valid date and time" : "Adăugați o dată validă și o oră",
     "Please select a time zone:" : "Te rugăm să alegeți un fus orar:",
     "Pick a time" : "Alege un interval orar",
     "Pick a date" : "Alege o dată",
+    "Type to search time zone" : "Tastați pentru căutare zonă de timp",
     "Global" : "Global",
+    "Holidays in {region}" : "Sărbători în {region}",
+    "Public holiday calendars" : "Calendare de sărbători legale",
+    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Calendarele de sărbători legale sunt furnizate de Thunderbird. Datele calendarului vor fi descărcate de la {website}",
+    "By {authors}" : "Autor {authors}",
+    "Subscribed" : "Subscris",
+    "Subscribe" : "Abonare",
+    "Could not fetch slots" : "Nu se pot prelua intervalele",
+    "Select slot" : "Selectați intervalul",
+    "No slots available" : "Nu sunt intervale disponibile",
+    "The slot for your appointment has been confirmed" : "Intervalul pentru întâlnire a fost confirmat",
+    "Appointment Details:" : "Detaliile programării:",
     "Time:" : "Timp:",
     "Booked for:" : "Rezervat pentru:",
+    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Mulțumim. Rezervarea din {startDate} pînă în {endDate} a fost confirmată.",
+    "Book another appointment:" : "Rezervați o altă programare:",
+    "See all available slots" : "Vezi toate intervalele disponibile",
+    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Intervalul întâlnirii din {startDate} până în {endDate} nu mai este disponibil.",
+    "Please book a different slot:" : "Rezervați un alt interval:",
+    "Book an appointment with {name}" : "Rezervați o programare cu {name}",
+    "No public appointments found for {name}" : "Nu sunt programări publice pentru {name}",
     "Personal" : "Personal",
-    "Details" : "Detalii",
-    "Attendees" : "Participanți",
+    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "A fost detectată automat zona de timp ca fiind UTC.\nProbabil ca măsura de securitate în cadrul browserului.\nSetați zona de timp manual în setările Calendar.",
+    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Zona de timp ({timezoneId}) nu există. Se revenire la UTC.\nModificați zona de timp în setări și raportați această problemă.",
+    "Edit event" : "Modifică eveniment",
+    "Event does not exist" : "Evenimentul nu există",
+    "Duplicate" : "Duplicat",
+    "Delete this occurrence" : "Șterge această poziție",
+    "Delete this and all future" : "Șterge aceasta și toate viitoare",
+    "All day" : "Toată ziua",
+    "Managing shared access" : "Configurare acces partajat",
+    "Deny access" : "Refuză accesul",
+    "Invite" : "Invită",
+    "_User requires access to your file_::_Users require access to your file_" : ["Utilizatorul necesită acces la fișier","Utilizatorii necesită acces la fișier","Utilizatorii necesită acces la fișier"],
+    "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Atașament care necesită acces partajat","Atașamente care necesită acces partajat","Atașamente care necesită acces partajat"],
+    "Untitled event" : "Eveniment fără titlu",
     "Close" : "Închide",
+    "Title" : "Titlu",
+    "Participants" : "Participanți",
+    "Submit" : "Trimite",
+    "Subscribe to {name}" : "Abonare la {name}",
+    "Export {name}" : "Exportă {name}",
     "Anniversary" : "Aniversare",
+    "Appointment" : "Programare",
+    "Business" : "Afacere",
+    "Education" : "Educație",
+    "Holiday" : "Sărbătoare",
+    "Meeting" : "Videoconferință",
+    "Miscellaneous" : "Diverse",
+    "Non-working hours" : "După program",
+    "Not in office" : "Plecat",
+    "Phone call" : "Apel telefonic",
+    "Sick day" : "Bolnav",
+    "Special occasion" : "Ocazie specială",
+    "Travel" : "Călătorie",
     "Vacation" : "Vacanță",
     "Midnight on the day the event starts" : "La miezul nopții în ziua în care evenimentul începe",
     "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : [" %n zi înainte de evenimentul de la {formattedHourMinute}","%n zile înainte de evenimentul de la {formattedHourMinute}","%n de zile înainte de evenimentul de la {formattedHourMinute}"],
@@ -303,28 +437,28 @@ OC.L10N.register(
     "on {time}" : "la {time}",
     "on {time} ({timezoneId})" : "la {time} ({timezoneId})",
     "Week {number} of {year}" : "Săptămâna {number} din {year}",
-    "Does not repeat" : "Nu se repetă",
     "Daily" : "Zilnic",
     "Weekly" : "Săptămânal",
     "Monthly" : "Lunar",
     "Yearly" : "Anual",
     "_Every %n day_::_Every %n days_" : ["La fiecare %n zi","La fiecare %n zile","La fiecare %n de zile"],
     "_Every %n week_::_Every %n weeks_" : ["La fiecare %n zi","La fiecare %n săptămâni","La fiecare %n de săptămâni"],
-    "_Every %n month_::_Every %n months_" : ["La fiecare %n lună","La fiecare luni","La fiecare %n de luni"],
+    "_Every %n month_::_Every %n months_" : ["La fiecare %n lună","La fiecare %n luni","La fiecare %n luni"],
     "_Every %n year_::_Every %n years_" : ["La fiecare %n an","La fiecare %n ani","La fiecare %n de ani"],
     "_on {weekday}_::_on {weekdays}_" : ["în {weekdays}","în {weekdays}","în {weekdays}"],
     "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["în ziua de {dayOfMonthList}","în zilele de {dayOfMonthList}","în zilele de {dayOfMonthList}"],
-    "in {monthNames}" : "în {monthNames}",
+    "on the {ordinalNumber} {byDaySet}" : "pe {ordinalNumber} {byDaySet}",
+    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "în {monthNames} pe {ordinalNumber} {byDaySet}",
     "until {untilDate}" : "până {untilDate}",
     "_%n time_::_%n times_" : ["%n zi","%n zile","%n de zile"],
-    "Untitled event" : "Eveniment fără titlu",
+    "second" : "secundă",
+    "third" : "al treilea",
+    "fourth" : "al patrulea",
+    "fifth" : "al cincilea",
+    "second to last" : "penultimul",
+    "last" : "ultimul",
     "Untitled task" : "Sarcină fără titlu",
     "Please ask your administrator to enable the Tasks App." : "Vă rugăm să întrebați administratorul dmneavoastră să pornească aplicația Task.",
-    "Prev" : "Precedent",
-    "Next" : "Următorul",
-    "Prev year" : "Anul anterior",
-    "Next year" : "Aanul viitor",
-    "Year" : "An",
     "W" : "W",
     "%n more" : "%n mai mult",
     "No events to display" : "Nu sunt evenimente de afișat",
@@ -343,7 +477,6 @@ OC.L10N.register(
     "When shared hide this event" : "Ascunde evenimentul la partajare",
     "The visibility of this event in shared calendars." : "Vizibilitatea acestui eveniment în calendarele partajate.",
     "Add a location" : "Adaugă o locație",
-    "Add a description" : "Adauga o descripție",
     "Status" : "Stare",
     "Confirmed" : "Confirmat",
     "Canceled" : "Anulat",
@@ -351,59 +484,24 @@ OC.L10N.register(
     "Show as" : "Arată-ne",
     "Take this event into account when calculating free-busy information." : "Ține cont de acest eveniment în momentul calculării timpului liber.",
     "Categories" : "Categorii",
-    "Commuting" : "În deplasare",
-    "Talk" : "Discuție",
-    "Movie" : "Film",
-    "Mail" : "Mail",
-    "Sports" : "Sport",
-    "Exercise" : "Exerciții fizice",
-    "Work out" : "Antrenament",
-    "Working out" : "Antrenare",
-    "Gym" : "Sală de sport",
-    "Barber" : "Frizerie",
-    "Haircut" : "Tunsoare",
-    "Hairdresser" : "Frizer",
-    "Exam" : "Examen",
-    "Written test" : "Test scris",
-    "Oral test" : "Test oral",
-    "Working" : "Muncă",
-    "New Years Eve" : "Revelion",
-    "NYE" : "NYE",
-    "Fireworks" : "Artificii",
-    "Running" : "Alergat",
-    "Go for a run" : "Dute la alergat",
-    "Marathon" : "on",
-    "Video-conference" : "Conferință video",
-    "Conference-call" : "Apel tip conferință",
-    "Video-call" : "Apel video",
-    "Video-chat" : "Apel video",
-    "Video-meeting" : "Șediță video",
-    "Calling" : "Apelare",
-    "Christmas" : "Crăciun",
-    "Conference" : "Conferință",
-    "Pizza" : "Pizza",
-    "Travelling" : "Călătorie",
-    "Trip" : "Excursie",
-    "Journey" : "Călătorie",
-    "Collaborate" : "Colaborează",
-    "Pair" : "Pereche",
-    "Lecture" : "Ore de curs",
-    "Seminar" : "Seminar",
-    "Teaching" : "Predare",
-    "Photograph" : "Fotografie",
-    "Party" : "Petrecere",
-    "Celebration" : "Sărbătorire",
-    "Celebrate" : "Serbează",
-    "Birthday" : "Zi de naștere",
-    "Shopping" : "Shopping",
-    "Groceries" : "Cumpărături",
-    "Skate" : "Skate",
-    "Skateboard" : "Skateboard",
-    "Wine tasting" : "Degustare de vin",
-    "Golf" : "Golf",
-    "Dinner" : "Cină",
-    "Lunch" : "Prânz",
+    "Categories help you to structure and organize your events." : "Categoriile ajută la structurarea și organizarea evenimentelor.",
+    "Search or add categories" : "Căutare sau adăugare categorii",
+    "Add this as a new category" : "Adaugă aceasta ca nouă categorie",
+    "Custom color" : "Culoare particulară",
+    "Special color of this event. Overrides the calendar-color." : "Culoare specială pentru eveniment. Nu ține cont de culoarea calendarului.",
+    "Error while sharing file" : "Eroare la partajarea fișierului",
+    "Error while sharing file with user" : "Eroare la partajarea fișierului cu utilizatorul",
+    "Attachment {fileName} already exists!" : "Atașamentul {fileName} există!",
+    "An error occurred during getting file information" : "Eroare la preluarea informațiilor despre fișier",
+    "An error occurred, unable to delete the calendar." : "A apărut o eroare, nu se poate șterge calendarul.",
+    "Imported {filename}" : "S-a importat {filename}",
+    "This is an event reminder." : "Acesta este un memento pentru eveniment.",
     "Appointment not found" : "Programarea nu a fost găsită",
-    "User not found" : "Utilizatorul nu a fost găsit"
+    "User not found" : "Utilizatorul nu a fost găsit",
+    "Shortcut overview" : "Prezentare generală a comenzilor rapide",
+    "Enable simplified editor" : "Activează editorul simplificat",
+    "Limit the number of events displayed in the monthly view" : "Limitează numărul evenimentelor în vizualizare lunară",
+    "Time increments" : "Incremente de timp",
+    "Show keyboard shortcuts" : "Arată scurtături"
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
