@@ -165,6 +165,7 @@ OC.L10N.register(
     "Automatic" : "Samodejno",
     "Automatic ({detected})" : "Samodejno ({detected})",
     "New setting was not saved successfully." : "Novih nastavitev ni bilo mogoče shraniti.",
+    "Timezone" : "Časovni pas",
     "Navigation" : "Krmarjenje",
     "Previous period" : "Predhodno obdobje",
     "Next period" : "Naslednje obdobje",
@@ -182,26 +183,24 @@ OC.L10N.register(
     "Save edited event" : "Shrani spremenjen dogodek",
     "Delete edited event" : "Izbriši spremenjen dogodek",
     "Duplicate event" : "Podvoji dogodek",
-    "Shortcut overview" : "Pregled tipkovnih bližnjic",
     "or" : "ali",
     "Calendar settings" : "Nastavitve koledarja",
     "No reminder" : "Brez opomnika",
     "Failed to save default calendar" : "Shranjevanje privzetega koledarja je spodletelo",
     "CalDAV link copied to clipboard." : "Povezava CalDAV je kopirana v odložišče.",
     "CalDAV link could not be copied to clipboard." : "Povezave CalDAV ni mogoče kopirati v odložišče.",
-    "Enable birthday calendar" : "Omogoči koledar rojstnih dni",
-    "Show tasks in calendar" : "Pokaži naloge v koledarju",
-    "Enable simplified editor" : "Omogoči poenostavljen urejevalnik",
-    "Limit the number of events displayed in the monthly view" : "Omeji število dogodkov v pogledu meseca",
-    "Show weekends" : "Pokaži vikende",
-    "Show week numbers" : "Pokaži številke tednov",
-    "Time increments" : "Časovno povečevanje",
-    "Default calendar for incoming invitations" : "Privzeti koledar za prihajajoča povabila",
-    "Default reminder" : "Privzeti opomnik",
+    "General" : "Splošno",
+    "Personal availability settings" : "Nastavitve osebne dejavnosti",
     "Copy primary CalDAV address" : "Kopiraj osnovni naslov CalDAV",
     "Copy iOS/macOS CalDAV address" : "Kopiraj naslov CalDAV za iOS/macOS",
-    "Personal availability settings" : "Nastavitve osebne dejavnosti",
-    "Show keyboard shortcuts" : "Pokaži tipkovne bližnjice",
+    "Enable birthday calendar" : "Omogoči koledar rojstnih dni",
+    "Show tasks in calendar" : "Pokaži naloge v koledarju",
+    "Show weekends" : "Pokaži vikende",
+    "Show week numbers" : "Pokaži številke tednov",
+    "Editing" : "Urejanje",
+    "Default calendar for incoming invitations" : "Privzeti koledar za prihajajoča povabila",
+    "Default reminder" : "Privzeti opomnik",
+    "Keyboard shortcuts" : "Tipkovne bližnjice",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minuta","{duration} minuti","{duration} minute","{duration} minut"],
     "0 minutes" : "0 minut",
     "_{duration} hour_::_{duration} hours_" : ["{duration} ura","{duration} uri","{duration} ure","{duration} ur"],
@@ -380,6 +379,7 @@ OC.L10N.register(
     "Maybe the share was deleted or has expired?" : "Morda je mesto souporabe izbrisano ali je časovno poteklo.",
     "Remove participant" : "Odstrani udeležence",
     "Yes" : "Da",
+    "No" : "Ne",
     "Maybe" : "Morda",
     "Create" : "Ustvari",
     "from {formattedDate}" : "od {formattedDate}",
@@ -436,7 +436,9 @@ OC.L10N.register(
     "Close" : "Zapri",
     "Selected" : "Izbrano",
     "Title" : "Naslov",
+    "30 min" : "30 min",
     "Participants" : "Udeleženci",
+    "Submit" : "Pošlji",
     "Subscribe to {name}" : "Naroči na {name}",
     "Export {name}" : "Izvozi {name}",
     "Anniversary" : "Obletnica",
@@ -526,6 +528,11 @@ OC.L10N.register(
     "Imported {filename}" : "Uvožena datoteka {filename}",
     "This is an event reminder." : "To je opomnik dogodka.",
     "Appointment not found" : "Sestanka ni mogoče najti",
-    "User not found" : "Uporabnika ni mogoče najti"
+    "User not found" : "Uporabnika ni mogoče najti",
+    "Shortcut overview" : "Pregled tipkovnih bližnjic",
+    "Enable simplified editor" : "Omogoči poenostavljen urejevalnik",
+    "Limit the number of events displayed in the monthly view" : "Omeji število dogodkov v pogledu meseca",
+    "Time increments" : "Časovno povečevanje",
+    "Show keyboard shortcuts" : "Pokaži tipkovne bližnjice"
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
