@@ -41,7 +41,17 @@ OC.L10N.register(
     "Comment:" : "Kommentar:",
     "You have a new appointment booking \"%s\" from %s" : "Du har en ny mötesbokning \"%s\" från %s",
     "Dear %s, %s (%s) booked an appointment with you." : "%s, %s (%s) bokade ett möte med dig.",
+    "%s has proposed a meeting" : "%s har föreslagit ett möte",
+    "%s has updated a proposed meeting" : "%s har uppdaterat ett föreslaget möte",
+    "%s has canceled a proposed meeting" : "%s har avbokat ett föreslaget möte",
+    "Dear %s, a new meeting has been proposed" : "Hej %s, ett nytt möte har föreslagits",
+    "Dear %s, a proposed meeting has been updated" : "Hej %s, ett föreslaget möte har uppdaterats",
+    "Dear %s, a proposed meeting has been cancelled" : "Hej %s, ett föreslaget möte har avbokats",
     "Location:" : "Ort:",
+    "Duration:" : "Varaktighet:",
+    "%1$s from %2$s to %3$s" : "%1$s från %2$s till %3$s",
+    "Dates:" : "Datum:",
+    "Respond" : "Svara",
     "A Calendar app for Nextcloud" : "En kalender-app för Nextcloud",
     "Previous day" : "Föregående dag",
     "Previous week" : "Föregående vecka",
@@ -148,6 +158,15 @@ OC.L10N.register(
     "Share calendar" : "Dela kalender",
     "Unshare from me" : "Sluta dela från mig",
     "Save" : "Spara",
+    "No title" : "Ingen titel",
+    "Are you sure you want to delete \"{title}\"?" : "Är du säker på att du vill ta bort \"{title}\"?",
+    "Deleting proposal \"{title}\"" : "Tar bort förslaget \"{title}\"",
+    "Successfully deleted proposal" : "Förslaget har tagits bort",
+    "Failed to delete proposal" : "Kunde inte ta bort förslaget",
+    "Failed to retrieve proposals" : "Kunde inte hämta förslag",
+    "Meeting proposals" : "Mötesförslag",
+    "A configured email address is required to use meeting proposals" : "En konfigurerad e-postadress krävs för att använda mötesförslag",
+    "No active meeting proposals" : "Inga aktiva mötesförslag",
     "View" : "Visa",
     "Import calendars" : "Importera kalendrar",
     "Please select a calendar to import into …" : "Vänligen välj en kalender du vill importera till …",
@@ -168,6 +187,7 @@ OC.L10N.register(
     "Automatic" : "Automatisk",
     "Automatic ({detected})" : "Automatisk ({detected})",
     "New setting was not saved successfully." : "Den nya inställningen kunde inte sparas.",
+    "Timezone" : "Tidszon",
     "Navigation" : "Navigering",
     "Previous period" : "Föregående period",
     "Next period" : "Nästa period",
@@ -185,7 +205,6 @@ OC.L10N.register(
     "Save edited event" : "Spara ändrad händelse",
     "Delete edited event" : "Radera ändrad händelse",
     "Duplicate event" : "Duplicera händelse",
-    "Shortcut overview" : "Översikt av genvägar",
     "or" : "eller",
     "Calendar settings" : "Kalenderinställningar",
     "At event start" : "Vid händelsens start",
@@ -193,19 +212,22 @@ OC.L10N.register(
     "Failed to save default calendar" : "Det gick inte att spara standardkalendern",
     "CalDAV link copied to clipboard." : "CalDAV-länk kopierad till urklipp.",
     "CalDAV link could not be copied to clipboard." : "CalDAV-länk kunde inte kopieras till urklipp.",
-    "Enable birthday calendar" : "Aktivera födelsedagskalender",
-    "Show tasks in calendar" : "Visa uppgifter i kalendern",
-    "Enable simplified editor" : "Aktivera förenklad redigerare",
-    "Limit the number of events displayed in the monthly view" : "Begränsa antalet händelser som visas i månadsvyn",
-    "Show weekends" : "Visa helger",
-    "Show week numbers" : "Visa veckonummer",
-    "Time increments" : "Tidsintervall",
-    "Default calendar for incoming invitations" : "Standardkalender för inkommande inbjudningar",
-    "Default reminder" : "Standardpåminnelse",
+    "General" : "Allmänt",
+    "Personal availability settings" : "Dina tillgänglighetsinställningar",
     "Copy primary CalDAV address" : "Kopiera primär CalDAV-adress",
     "Copy iOS/macOS CalDAV address" : "Kopiera iOS/macOS CalDAV-adress",
-    "Personal availability settings" : "Dina tillgänglighetsinställningar",
-    "Show keyboard shortcuts" : "Visa tangentbordsgenvägar",
+    "View options" : "Visningsalternativ",
+    "Enable birthday calendar" : "Aktivera födelsedagskalender",
+    "Show tasks in calendar" : "Visa uppgifter i kalendern",
+    "Show weekends" : "Visa helger",
+    "Show week numbers" : "Visa veckonummer",
+    "Limit number of events shown in month view" : "Begränsa antalet händelser som visas i månadsvyn",
+    "Time division in day and week view" : "Tidsindelning i dag- och vecko­vy",
+    "Editing" : "Ändrar",
+    "Enable simple editor" : "Aktivera enkel redigerare",
+    "Default calendar for incoming invitations" : "Standardkalender för inkommande inbjudningar",
+    "Default reminder" : "Standardpåminnelse",
+    "Keyboard shortcuts" : "Tangentbordsgenvägar",
     "Appointment schedule successfully created" : "Mötesschema skapat",
     "Appointment schedule successfully updated" : "Mötesschema uppdaterat",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minut","{duration} minuter"],
@@ -425,9 +447,17 @@ OC.L10N.register(
     "Update this occurrence" : "Uppdatera denna förekomst",
     "Public calendar does not exist" : "Publik kalender finns inte",
     "Maybe the share was deleted or has expired?" : "Kanske har delningen tagits bort eller har gått ut?",
+    "Remove date" : "Ta bort datum",
+    "Attendance required" : "Närvaro krävs",
+    "Attendance optional" : "Närvaro frivillig",
+    "Remove participant" : "Ta bort deltagare",
     "Yes" : "Ja",
+    "No" : "Nej",
     "Maybe" : "Kanske",
+    "Select your meeting availability" : "Välj din tillgänglighet",
+    "Create a meeting for this date and time" : "Skapa ett möte för detta datum och tid",
     "Create" : "Skapa",
+    "No participants or dates available" : "Inga deltagare eller datum tillgängliga",
     "from {formattedDate}" : "från {formattedDate}",
     "to {formattedDate}" : "till {formattedDate}",
     "on {formattedDate}" : "på {formattedDate}",
@@ -491,8 +521,47 @@ OC.L10N.register(
     "Untitled event" : "Namnlös händelse",
     "Close" : "Stäng",
     "Modifications will not get propagated to the organizer and other attendees" : "Ändringar kommer inte att skickas till organisatören eller andra deltagare",
+    "Meeting proposals overview" : "Översikt över mötesförslag",
+    "Edit meeting proposal" : "Redigera mötesförslag",
+    "Create meeting proposal" : "Skapa mötesförslag",
+    "Update meeting proposal" : "Uppdatera mötesförslag",
+    "Saving proposal \"{title}\"" : "Sparar förslag \"{title}\"",
+    "Successfully saved proposal" : "Förslaget har sparats",
+    "Failed to save proposal" : "Kunde inte spara förslaget",
+    "Create a meeting for \"{date}\"? This will create a calendar event with all participants." : "Skapa ett möte för \"{date}\"? Detta kommer att skapa en kalenderhändelse med alla deltagare.",
+    "Creating meeting for {date}" : "Skapar möte för {date}",
+    "Successfully created meeting for {date}" : "Möte har skapats för {date}",
+    "Failed to create a meeting for {date}" : "Kunde inte skapa möte för {date}",
+    "Please enter a valid duration in minutes." : "Ange en giltig varaktighet i minuter.",
+    "Failed to fetch proposals" : "Kunde inte hämta förslag",
+    "Failed to fetch free/busy data" : "Kunde inte hämta ledig/upptagen-data",
+    "Selected" : "Vald",
+    "No Description" : "Ingen beskrivning",
+    "No Location" : "Ingen plats",
+    "Edit this meeting proposal" : "Redigera detta mötesförslag",
+    "Delete this meeting proposal" : "Ta bort detta mötesförslag",
     "Title" : "Titel",
+    "15 min" : "15 min",
+    "30 min" : "30 min",
+    "60 min" : "60 min",
+    "90 min" : "90 min",
     "Participants" : "Deltagare",
+    "Selected times" : "Valda tider",
+    "Previous span" : "Föregående intervall",
+    "Next span" : "Nästa intervall",
+    "Less days" : "Färre dagar",
+    "More days" : "Fler dagar",
+    "Loading meeting proposal" : "Läser in mötesförslag",
+    "No meeting proposal found" : "Inget mötesförslag hittades",
+    "Please wait while we load the meeting proposal." : "Vänligen vänta medan vi läser in mötesförslaget.",
+    "The link you followed may be broken, or the meeting proposal may no longer exist." : "Länken du följde kan vara trasig, eller så finns mötesförslaget inte längre.",
+    "Thank you for your response!" : "Tack för ditt svar!",
+    "Your vote has been recorded. Thank you for participating!" : "Din röst har registrerats. Tack för att du deltog!",
+    "Unknown User" : "Okänd användare",
+    "No Title" : "Ingen titel",
+    "No Duration" : "Ingen varaktighet",
+    "Select a different time zone" : "Välj en annan tidszon",
+    "Submit" : "Skicka",
     "Subscribe to {name}" : "Prenumerera på {name}",
     "Export {name}" : "Exportera {name}",
     "Show availability" : "Visa tillgänglighet",
@@ -596,6 +665,11 @@ OC.L10N.register(
     "This is an event reminder." : "Detta är en händelsepåminnelse.",
     "Error while parsing a PROPFIND error" : "Fel vid analys av ett PROPFIND-fel",
     "Appointment not found" : "Mötet hittades inte",
-    "User not found" : "Användaren hittades inte"
+    "User not found" : "Användaren hittades inte",
+    "Shortcut overview" : "Översikt av genvägar",
+    "Enable simplified editor" : "Aktivera förenklad redigerare",
+    "Limit the number of events displayed in the monthly view" : "Begränsa antalet händelser som visas i månadsvyn",
+    "Time increments" : "Tidsintervall",
+    "Show keyboard shortcuts" : "Visa tangentbordsgenvägar"
 },
 "nplurals=2; plural=(n != 1);");
