@@ -180,7 +180,6 @@ OC.L10N.register(
     "Save edited event" : "تەھرىرلەنگەن پائالىيەتنى ساقلاڭ",
     "Delete edited event" : "تەھرىرلەنگەن ۋەقەنى ئۆچۈرۈڭ",
     "Duplicate event" : "كۆپەيتىلگەن ھادىسە",
-    "Shortcut overview" : "تېزلەتمە ئومۇمىي كۆرۈنۈش",
     "or" : "ياكى",
     "Calendar settings" : "كالېندار تەڭشىكى",
     "At event start" : "پائالىيەت باشلانغاندا",
@@ -188,19 +187,18 @@ OC.L10N.register(
     "Failed to save default calendar" : "سۈكۈتتىكى كالېندارنى ساقلىيالمىدى",
     "CalDAV link copied to clipboard." : "CalDAV ئۇلىنىشى چاپلاش تاختىسىغا كۆچۈرۈلدى.",
     "CalDAV link could not be copied to clipboard." : "CalDAV ئۇلانمىسىنى چاپلاش تاختىسىغا كۆچۈرگىلى بولمايدۇ.",
-    "Enable birthday calendar" : "تۇغۇلغان كۈن كالىندارىنى قوزغىتىڭ",
-    "Show tasks in calendar" : "كالېنداردىكى ۋەزىپىلەرنى كۆرسەت",
-    "Enable simplified editor" : "ئاددىيلاشتۇرۇلغان تەھرىرلىگۈچنى قوزغىتىڭ",
-    "Limit the number of events displayed in the monthly view" : "ئايلىق كۆرۈنۈشتە كۆرسىتىلگەن پائالىيەت سانىنى چەكلەڭ",
-    "Show weekends" : "ھەپتە ئاخىرىنى كۆرسەت",
-    "Show week numbers" : "ھەپتە نومۇرىنى كۆرسەت",
-    "Time increments" : "ۋاقىت كۆپەيدى",
-    "Default calendar for incoming invitations" : "كەلگەن تەكلىپلەرنىڭ سۈكۈتتىكى كالېندارى",
-    "Default reminder" : "كۆڭۈلدىكى ئەسكەرتىش",
+    "General" : "General",
+    "Personal availability settings" : "شەخسىي ئىشلىتىش تەڭشىكى",
     "Copy primary CalDAV address" : "دەسلەپكى CalDAV ئادرېسىنى كۆچۈرۈڭ",
     "Copy iOS/macOS CalDAV address" : "IOS / macOS CalDAV ئادرېسىنى كۆچۈرۈڭ",
-    "Personal availability settings" : "شەخسىي ئىشلىتىش تەڭشىكى",
-    "Show keyboard shortcuts" : "كۇنۇپكا تاختىسىنىڭ تېزلەتمىسىنى كۆرسەت",
+    "Enable birthday calendar" : "تۇغۇلغان كۈن كالىندارىنى قوزغىتىڭ",
+    "Show tasks in calendar" : "كالېنداردىكى ۋەزىپىلەرنى كۆرسەت",
+    "Show weekends" : "ھەپتە ئاخىرىنى كۆرسەت",
+    "Show week numbers" : "ھەپتە نومۇرىنى كۆرسەت",
+    "Editing" : "تەھرىرلەش",
+    "Default calendar for incoming invitations" : "كەلگەن تەكلىپلەرنىڭ سۈكۈتتىكى كالېندارى",
+    "Default reminder" : "كۆڭۈلدىكى ئەسكەرتىش",
+    "Keyboard shortcuts" : "كۇنۇپكا تاختىسى تېزلەتمىسى",
     "Appointment schedule successfully created" : "تەيىنلەش جەدۋىلى مۇۋەپپەقىيەتلىك قۇرۇلدى",
     "Appointment schedule successfully updated" : "تەيىنلەش جەدۋىلى مۇۋەپپەقىيەتلىك يېڭىلاندى",
     "0 minutes" : "0 مىنۇت",
@@ -440,7 +438,9 @@ OC.L10N.register(
     "Close" : "ياپ",
     "Selected" : "تاللانغان",
     "Title" : "ماۋزۇ",
+    "30 min" : "30 مىنۇت",
     "Participants" : "قاتناشقۇچىلار",
+    "Submit" : "يوللاڭ",
     "Subscribe to {name}" : "{name} غا مۇشتەرى بولۇڭ",
     "Export {name}" : "چىقىرىش {name}",
     "Anniversary" : "يىللىق خاتىرە كۈنى",
@@ -522,6 +522,11 @@ OC.L10N.register(
     "This is an event reminder." : "بۇ بىر ۋەقە ئەسكەرتىش.",
     "Error while parsing a PROPFIND error" : "PROPFIND خاتالىقىنى تەھلىل قىلغاندا خاتالىق",
     "Appointment not found" : "تەيىنلەنمىدى",
-    "User not found" : "ئىشلەتكۈچى تېپىلمىدى"
+    "User not found" : "ئىشلەتكۈچى تېپىلمىدى",
+    "Shortcut overview" : "تېزلەتمە ئومۇمىي كۆرۈنۈش",
+    "Enable simplified editor" : "ئاددىيلاشتۇرۇلغان تەھرىرلىگۈچنى قوزغىتىڭ",
+    "Limit the number of events displayed in the monthly view" : "ئايلىق كۆرۈنۈشتە كۆرسىتىلگەن پائالىيەت سانىنى چەكلەڭ",
+    "Time increments" : "ۋاقىت كۆپەيدى",
+    "Show keyboard shortcuts" : "كۇنۇپكا تاختىسىنىڭ تېزلەتمىسىنى كۆرسەت"
 },
 "nplurals=2; plural=(n != 1);");
